@@ -153,28 +153,41 @@ void CanvasMode_EyeDropper::mouseReleaseEvent(QMouseEvent *m)
 	releaseMouse();
 
 	m_view->setCursor(QCursor(Qt::ArrowCursor));
-	QPixmap pm;
-	QScreen *screen = QGuiApplication::primaryScreen();
-	if (screen)
-		pm = screen->grabWindow( QApplication::desktop()->winId(), m->globalPos().x(), m->globalPos().y(), 1, 1);
-	QImage i = pm.toImage();
-	QColor selectedColor = i.pixel(0, 0);
 
-	bool found = false;
-	ColorList::Iterator it;
-	for (it = m_doc->PageColors.begin(); it != m_doc->PageColors.end(); ++it)
+	QPixmap pm;
+	QWidget* pWidget = QApplication::widgetAt(m->globalPos());
+	if (pWidget)
+	{
+		// This works on Wayland contrary to the QScreen::grabWindow() solution,
+		// but only if clicked point is inside Scribus application
+		auto localPos = pWidget->mapFromGlobal(m->globalPos());
+		pm = pWidget->grab(QRect(localPos.x(), localPos.y(), 1, 1));
+	}
+	else
+	{
+		QScreen* screen = QGuiApplication::primaryScreen();
+		if (screen)
+			pm = screen->grabWindow(QApplication::desktop()->winId(), m->globalPos().x(), m->globalPos().y(), 1, 1);
+	}
+	if (pm.isNull())
+	{
+		m_view->requestMode(modeNormal);
+		return;
+	}
+	QImage img = pm.toImage();
+	QColor selectedColor = img.pixel(0, 0);
+
+	QString colorName;
+	for (auto it = m_doc->PageColors.begin(); it != m_doc->PageColors.end(); ++it)
 	{
 		if (selectedColor == ScColorEngine::getRGBColor(it.value(), m_doc))
 		{
-			found = true;
+			colorName = it.key();
 			break;
 		}
 	}
 
-	QString colorName;
-	if (found)
-		colorName = it.key();
-	else
+	if (colorName.isEmpty())
 	{
 		bool ok;
 		bool nameFound = false;
@@ -201,10 +214,10 @@ void CanvasMode_EyeDropper::mouseReleaseEvent(QMouseEvent *m)
 		}
 	}
 
-	uint docSelectionCount = m_doc->m_Selection->count();
+	int docSelectionCount = m_doc->m_Selection->count();
 	if (!colorName.isEmpty() && docSelectionCount > 0)
 	{
-		for (uint i = 0; i < docSelectionCount; ++i)
+		for (int i = 0; i < docSelectionCount; ++i)
 		{
 			PageItem *currItem = m_doc->m_Selection->itemAt(i);
 			if (!currItem)
