@@ -123,8 +123,8 @@ void CanvasMode_Rotate::getNewItemPosition(PageItem* item, FPoint& pos, double&
 		switch (m_rotMode)
 		{
 		case 2:
-			ma.translate(item->width()/2.0, item->height()/2.0);
-			n = FPoint(-item->width()/2.0, -item->height()/2.0);
+			ma.translate(item->width() / 2.0, item->height() / 2.0);
+			n = FPoint(-item->width() / 2.0, -item->height() / 2.0);
 			break;
 		case 4:
 			ma.translate(item->width(), item->height());
@@ -416,7 +416,7 @@ void CanvasMode_Rotate::mouseMoveEvent(QMouseEvent *m)
 					break;
 				QTransform p;
 				m_canvas->Transform(currItem, p);
-				QRect mpo = QRect(m->x() - m_doc->guidesPrefs().grabRadius, m->y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
+				QRect mpo(m->x() - m_doc->guidesPrefs().grabRadius, m->y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
 				if ((QRegion(p.map(QPolygon(QRect(-3, -3, static_cast<int>(currItem->width() + 6), static_cast<int>(currItem->height() + 6))))).contains(mpo)))
 				{
 					QRect tx = p.mapRect(QRect(0, 0, static_cast<int>(currItem->width()), static_cast<int>(currItem->height())));
