@@ -24,185 +24,200 @@ for which a new license (GPL+exception) is in place.
 #include "commonstrings.h"
 #include "units.h"
 
-QString CommonStrings::_Apply      = "";
-QString CommonStrings::tr_Apply    = "";
-QString CommonStrings::_Cancel     = "";
-QString CommonStrings::tr_Cancel   = "";
-QString CommonStrings::None        = "";
-QString CommonStrings::tr_None     = "";
-QString CommonStrings::tr_NoneColor= "";
-QString CommonStrings::_OK         = "";
-QString CommonStrings::tr_OK       = "";
-QString CommonStrings::_Save       = "";
-QString CommonStrings::tr_Save     = "";
-QString CommonStrings::Warning     = "";
-QString CommonStrings::trWarning   = "";
+QString CommonStrings::_Apply;
+QString CommonStrings::tr_Apply;
+QString CommonStrings::_Cancel;
+QString CommonStrings::tr_Cancel;
+QString CommonStrings::None;
+QString CommonStrings::tr_None;
+QString CommonStrings::tr_NoneColor;
+QString CommonStrings::_OK;
+QString CommonStrings::tr_OK;
+QString CommonStrings::_Save;
+QString CommonStrings::tr_Save;
+QString CommonStrings::Warning;
+QString CommonStrings::trWarning;
 
-QString CommonStrings::trYes       = "";
-QString CommonStrings::trNo        = "";
-QString CommonStrings::trYesKey    = "";
-QString CommonStrings::trNoKey     = "";
+QString CommonStrings::trYes;
+QString CommonStrings::trNo;
+QString CommonStrings::trYesKey;
+QString CommonStrings::trNoKey;
 
-QString CommonStrings::customPageSize = "";
-QString CommonStrings::trCustomPageSize = "";
+QString CommonStrings::customPageSize;
+QString CommonStrings::trCustomPageSize;
 
-QString CommonStrings::itemType_TextFrame		= "";
-QString CommonStrings::itemType_ImageFrame		= "";
-QString CommonStrings::itemType_Line			= "";
-QString CommonStrings::itemType_Polygon			= "";
-QString CommonStrings::itemType_Polyline		= "";
-QString CommonStrings::itemType_PathText		= "";
-QString CommonStrings::itemType_LatexFrame		= "";
-QString CommonStrings::itemType_OSGFrame		= "";
-QString CommonStrings::itemType_Symbol			= "";
-QString CommonStrings::itemType_Group			= "";
-QString CommonStrings::itemType_RegularPolygon	= "";
-QString CommonStrings::itemType_Arc				= "";
-QString CommonStrings::itemType_Spiral			= "";
-QString CommonStrings::itemType_Table			= "";
-QString CommonStrings::itemType_Multiple		= "";
+QString CommonStrings::itemType_TextFrame;
+QString CommonStrings::itemType_ImageFrame;
+QString CommonStrings::itemType_Line;
+QString CommonStrings::itemType_Polygon;
+QString CommonStrings::itemType_Polyline;
+QString CommonStrings::itemType_PathText;
+QString CommonStrings::itemType_LatexFrame;
+QString CommonStrings::itemType_OSGFrame;
+QString CommonStrings::itemType_Symbol;
+QString CommonStrings::itemType_Group;
+QString CommonStrings::itemType_RegularPolygon;
+QString CommonStrings::itemType_Arc;
+QString CommonStrings::itemType_Spiral;
+QString CommonStrings::itemType_Table;
+QString CommonStrings::itemType_Multiple;
 
-QString CommonStrings::itemSubType_PDF_PushButton		= "";
-QString CommonStrings::itemSubType_PDF_RadioButton		= "";
-QString CommonStrings::itemSubType_PDF_TextField		= "";
-QString CommonStrings::itemSubType_PDF_CheckBox			= "";
-QString CommonStrings::itemSubType_PDF_ComboBox			= "";
-QString CommonStrings::itemSubType_PDF_ListBox			= "";
-QString CommonStrings::itemSubType_PDF_TextAnnotation	= "";
-QString CommonStrings::itemSubType_PDF_LinkAnnotation	= "";
-QString CommonStrings::itemName_PushButton				= "";
-QString CommonStrings::itemName_RadioButton				= "";
-QString CommonStrings::itemName_TextField				= "";
-QString CommonStrings::itemName_CheckBox				= "";
-QString CommonStrings::itemName_ComboBox				= "";
-QString CommonStrings::itemName_ListBox					= "";
-QString CommonStrings::itemName_TextAnnotation			= "";
-QString CommonStrings::itemName_LinkAnnotation			= "";
+QString CommonStrings::itemSubType_PDF_PushButton;
+QString CommonStrings::itemSubType_PDF_RadioButton;
+QString CommonStrings::itemSubType_PDF_TextField;
+QString CommonStrings::itemSubType_PDF_CheckBox;
+QString CommonStrings::itemSubType_PDF_ComboBox;
+QString CommonStrings::itemSubType_PDF_ListBox;
+QString CommonStrings::itemSubType_PDF_TextAnnotation;
+QString CommonStrings::itemSubType_PDF_LinkAnnotation;
+QString CommonStrings::itemName_PushButton;
+QString CommonStrings::itemName_RadioButton;
+QString CommonStrings::itemName_TextField;
+QString CommonStrings::itemName_CheckBox;
+QString CommonStrings::itemName_ComboBox;
+QString CommonStrings::itemName_ListBox;
+QString CommonStrings::itemName_TextAnnotation;
+QString CommonStrings::itemName_LinkAnnotation;
 
 
-QString CommonStrings::pageSet1    = "";
-QString CommonStrings::pageSet2    = "";
-QString CommonStrings::pageSet3    = "";
-QString CommonStrings::pageSet4    = "";
-QString CommonStrings::trPageSet1  = "";
-QString CommonStrings::trPageSet2  = "";
-QString CommonStrings::trPageSet3  = "";
-QString CommonStrings::trPageSet4  = "";
-QString CommonStrings::pageLocLeft          = "";
-QString CommonStrings::pageLocMiddle        = "";
-QString CommonStrings::pageLocMiddleLeft    = "";
-QString CommonStrings::pageLocMiddleRight   = "";
-QString CommonStrings::pageLocRight         = "";
-QString CommonStrings::trPageLocLeft        = "";
-QString CommonStrings::trPageLocMiddle      = "";
-QString CommonStrings::trPageLocMiddleLeft  = "";
-QString CommonStrings::trPageLocMiddleRight = "";
-QString CommonStrings::trPageLocRight       = "";
+QString CommonStrings::pageSet1;
+QString CommonStrings::pageSet2;
+QString CommonStrings::pageSet3;
+QString CommonStrings::pageSet4;
+QString CommonStrings::trPageSet1;
+QString CommonStrings::trPageSet2;
+QString CommonStrings::trPageSet3;
+QString CommonStrings::trPageSet4;
+QString CommonStrings::pageLocLeft;
+QString CommonStrings::pageLocMiddle;
+QString CommonStrings::pageLocMiddleLeft;
+QString CommonStrings::pageLocMiddleRight;
+QString CommonStrings::pageLocRight;
+QString CommonStrings::trPageLocLeft;
+QString CommonStrings::trPageLocMiddle;
+QString CommonStrings::trPageLocMiddleLeft;
+QString CommonStrings::trPageLocMiddleRight;
+QString CommonStrings::trPageLocRight;
 
-QString CommonStrings:: masterPageNormal         = "";
-QString CommonStrings:: trMasterPageNormal       = "";
-QString CommonStrings:: masterPageNormalLeft     = "";
-QString CommonStrings:: trMasterPageNormalLeft   = "";
-QString CommonStrings:: masterPageNormalMiddle   = "";
-QString CommonStrings:: trMasterPageNormalMiddle = "";
-QString CommonStrings:: masterPageNormalRight    = "";
-QString CommonStrings:: trMasterPageNormalRight  = "";
+QString CommonStrings:: masterPageNormal;
+QString CommonStrings:: trMasterPageNormal;
+QString CommonStrings:: masterPageNormalLeft;
+QString CommonStrings:: trMasterPageNormalLeft;
+QString CommonStrings:: masterPageNormalMiddle;
+QString CommonStrings:: trMasterPageNormalMiddle;
+QString CommonStrings:: masterPageNormalRight;
+QString CommonStrings:: trMasterPageNormalRight;
 
-QString CommonStrings::trPenStyle_SolidLine      = "";
-QString CommonStrings::trPenStyle_DashedLine     = "";
-QString CommonStrings::trPenStyle_DottedLine     = "";
-QString CommonStrings::trPenStyle_DashDotLine    = "";
-QString CommonStrings::trPenStyle_DashDotDotLine = "";
+QString CommonStrings::trPenStyle_SolidLine;
+QString CommonStrings::trPenStyle_DashedLine;
+QString CommonStrings::trPenStyle_DottedLine;
+QString CommonStrings::trPenStyle_DashDotLine;
+QString CommonStrings::trPenStyle_DashDotDotLine;
 
 
-QString CommonStrings::DefaultParagraphStyle     ="";
-QString CommonStrings::DefaultCharacterStyle     ="";
-QString CommonStrings::DefaultLineStyle          ="";
-QString CommonStrings::DefaultTableStyle         ="";
-QString CommonStrings::DefaultCellStyle          ="";
-QString CommonStrings::trDefaultParagraphStyle   ="";
-QString CommonStrings::trDefaultCharacterStyle   ="";
-QString CommonStrings::trDefaultLineStyle        ="";
-QString CommonStrings::trDefaultTableStyle       ="";
-QString CommonStrings::trDefaultCellStyle        ="";
+QString CommonStrings::DefaultParagraphStyle;
+QString CommonStrings::DefaultCharacterStyle;
+QString CommonStrings::DefaultLineStyle;
+QString CommonStrings::DefaultTableStyle;
+QString CommonStrings::DefaultCellStyle;
+QString CommonStrings::trDefaultParagraphStyle;
+QString CommonStrings::trDefaultCharacterStyle;
+QString CommonStrings::trDefaultLineStyle;
+QString CommonStrings::trDefaultTableStyle;
+QString CommonStrings::trDefaultCellStyle;
 
+QString CommonStrings::monday;
+QString CommonStrings::tuesday;
+QString CommonStrings::wednesday;
+QString CommonStrings::thursday;
+QString CommonStrings::friday;
+QString CommonStrings::saturday;
+QString CommonStrings::sunday;
 
-QString CommonStrings::monday="", CommonStrings::tuesday="", CommonStrings::wednesday="";
-QString CommonStrings::thursday="", CommonStrings::friday="", CommonStrings::saturday="", CommonStrings::sunday="";
-QString CommonStrings::january="", CommonStrings::february="", CommonStrings::march="";
-QString CommonStrings::april="", CommonStrings::may="", CommonStrings::june="";
-QString CommonStrings::july="", CommonStrings::august="", CommonStrings::september="";
-QString CommonStrings::october="", CommonStrings::november="", CommonStrings::december="";
+QString CommonStrings::january;
+QString CommonStrings::february;
+QString CommonStrings::march;
+QString CommonStrings::april;
+QString CommonStrings::may;
+QString CommonStrings::june;
+QString CommonStrings::july;
+QString CommonStrings::august;
+QString CommonStrings::september;
+QString CommonStrings::october;
+QString CommonStrings::november;
+QString CommonStrings::december;
 
-QString CommonStrings::trRGB       = "";
-QString CommonStrings::trCMYK      = "";
-QString CommonStrings::trGrayscale = "";
-QString CommonStrings::trDuotone   = "";
-QString CommonStrings::trMonochrome = "";
-QString CommonStrings::trUnknownCS = "";
+QString CommonStrings::trRGB;
+QString CommonStrings::trCMYK;
+QString CommonStrings::trGrayscale;
+QString CommonStrings::trDuotone;
+QString CommonStrings::trMonochrome;
+QString CommonStrings::trUnknownCS;
 
-QString CommonStrings::trVisionNormal         = "";
-QString CommonStrings::trVisionProtanopia     = "";
-QString CommonStrings::trVisionDeuteranopia   = "";
-QString CommonStrings::trVisionTritanopia     = "";
-QString CommonStrings::trVisionFullColorBlind = "";
+QString CommonStrings::trVisionNormal;
+QString CommonStrings::trVisionProtanopia;
+QString CommonStrings::trVisionDeuteranopia;
+QString CommonStrings::trVisionTritanopia;
+QString CommonStrings::trVisionFullColorBlind;
 
-QString CommonStrings::trCustomTabFill        = "";
+QString CommonStrings::trCustomTabFill;
 
-QString CommonStrings::trOpticalMarginsNone            = "";
-QString CommonStrings::trOpticalMarginsLeftProtruding  = "";
-QString CommonStrings::trOpticalMarginsRightProtruding = "";
-QString CommonStrings::trOpticalMarginsLeftHangPunct   = "";
-QString CommonStrings::trOpticalMarginsRightHangPunct  = "";
-QString CommonStrings::trOpticalMarginsDefault         = "";
+QString CommonStrings::trOpticalMarginsNone;
+QString CommonStrings::trOpticalMarginsLeftProtruding;
+QString CommonStrings::trOpticalMarginsRightProtruding;
+QString CommonStrings::trOpticalMarginsLeftHangPunct;
+QString CommonStrings::trOpticalMarginsRightHangPunct;
+QString CommonStrings::trOpticalMarginsDefault;
 
-QString CommonStrings::trMinWordTracking   = "";
-QString CommonStrings::trMaxWordTracking   = "";
-QString CommonStrings::trMinGlyphExtension = "";
-QString CommonStrings::trMaxGlyphExtension = "";
+QString CommonStrings::trMinWordTracking;
+QString CommonStrings::trMaxWordTracking;
+QString CommonStrings::trMinGlyphExtension;
+QString CommonStrings::trMaxGlyphExtension;
 
-QString CommonStrings::File         = "";
-QString CommonStrings::trFile       = "";
-QString CommonStrings::PostScript   = "";
-QString CommonStrings::trPostScript = "";
-QString CommonStrings::PDF          = "";
-QString CommonStrings::trPDF        = "";
-QString CommonStrings::PDF_1_3      = "";
-QString CommonStrings::PDF_1_4      = "";
-QString CommonStrings::PDF_1_5      = "";
-QString CommonStrings::PDF_1_6      = "";
-QString CommonStrings::PDF_X1a		= "";
-QString CommonStrings::PDF_X3       = "";
-QString CommonStrings::PDF_X4		= "";
+QString CommonStrings::File;
+QString CommonStrings::trFile;
+QString CommonStrings::PostScript;
+QString CommonStrings::trPostScript;
+QString CommonStrings::PDF;
+QString CommonStrings::trPDF;
+QString CommonStrings::PDF_1_3;
+QString CommonStrings::PDF_1_4;
+QString CommonStrings::PDF_1_5;
+QString CommonStrings::PDF_1_6;
+QString CommonStrings::PDF_X1a;
+QString CommonStrings::PDF_X3;
+QString CommonStrings::PDF_X4;
 
-QString CommonStrings::PostScript1   = "";
-QString CommonStrings::trPostScript1 = "";
-QString CommonStrings::PostScript2   = "";
-QString CommonStrings::trPostScript2 = "";
-QString CommonStrings::PostScript3   = "";
-QString CommonStrings::trPostScript3 = "";
-QString CommonStrings::WindowsGDI    = "";
-QString CommonStrings::trWindowsGDI  = "";
+QString CommonStrings::PostScript1;
+QString CommonStrings::trPostScript1;
+QString CommonStrings::PostScript2;
+QString CommonStrings::trPostScript2;
+QString CommonStrings::PostScript3;
+QString CommonStrings::trPostScript3;
+QString CommonStrings::WindowsGDI;
+QString CommonStrings::trWindowsGDI;
 
-QString CommonStrings::trStrPT = "";
-QString CommonStrings::trStrMM = "";
-QString CommonStrings::trStrIN = "";
-QString CommonStrings::trStrP  = "";
-QString CommonStrings::trStrCM = "";
-QString CommonStrings::trStrC  = "";
-QString CommonStrings::trStrPX = "";
-QString CommonStrings::strPT   = "";
-QString CommonStrings::strMM   = "";
-QString CommonStrings::strIN   = "";
-QString CommonStrings::strP    = "";
-QString CommonStrings::strCM   = "";
-QString CommonStrings::strC    = "";
-QString CommonStrings::strPX   = "";
+QString CommonStrings::trSectionName;
 
-QString CommonStrings::controlModifier = "";
-QString CommonStrings::altModifier     = "";
-QString CommonStrings::shiftModifier   = "";
-QString CommonStrings::metaModifier    = "";
+QString CommonStrings::trStrPT;
+QString CommonStrings::trStrMM;
+QString CommonStrings::trStrIN;
+QString CommonStrings::trStrP;
+QString CommonStrings::trStrCM;
+QString CommonStrings::trStrC;
+QString CommonStrings::trStrPX;
+QString CommonStrings::strPT;
+QString CommonStrings::strMM;
+QString CommonStrings::strIN;
+QString CommonStrings::strP;
+QString CommonStrings::strCM;
+QString CommonStrings::strC;
+QString CommonStrings::strPX;
+
+QString CommonStrings::controlModifier;
+QString CommonStrings::altModifier;
+QString CommonStrings::shiftModifier;
+QString CommonStrings::metaModifier;
 
 CommonStrings::CommonStrings()
 {
@@ -211,56 +226,56 @@ CommonStrings::CommonStrings()
 
 const QString& CommonStrings::translatePageSetString(const QString &untrString)
 {
-	if (untrString==pageSet1)
+	if (untrString == pageSet1)
 		return trPageSet1;
-	if (untrString==pageSet2)
+	if (untrString == pageSet2)
 		return trPageSet2;
-	if (untrString==pageSet3)
+	if (untrString == pageSet3)
 		return trPageSet3;
-	if (untrString==pageSet4)
+	if (untrString == pageSet4)
 		return trPageSet4;
 	return untrString;
 }
 
 const QString& CommonStrings::translatePageSetLocString(const QString &untrString)
 {
-	if (untrString==pageLocLeft)
+	if (untrString == pageLocLeft)
 		return trPageLocLeft;
-	if (untrString==pageLocMiddle)
+	if (untrString == pageLocMiddle)
 		return trPageLocMiddle;
-	if (untrString==pageLocMiddleLeft)
+	if (untrString == pageLocMiddleLeft)
 		return trPageLocMiddleLeft;
-	if (untrString==pageLocMiddleRight)
+	if (untrString == pageLocMiddleRight)
 		return trPageLocMiddleRight;
-	if (untrString==pageLocRight)
+	if (untrString == pageLocRight)
 		return trPageLocRight;
 	return untrString;
 }
 
 const QString& CommonStrings::untranslatePageSetString(const QString &trString)
 {
-	if (trString==trPageSet1)
+	if (trString == trPageSet1)
 		return pageSet1;
-	if (trString==trPageSet2)
+	if (trString == trPageSet2)
 		return pageSet2;
-	if (trString==trPageSet3)
+	if (trString == trPageSet3)
 		return pageSet3;
-	if (trString==trPageSet4)
+	if (trString == trPageSet4)
 		return pageSet4;
 	return trString;
 }
 
 const QString& CommonStrings::untranslatePageSetLocString(const QString &trString)
 {
-	if (trString==trPageLocLeft)
+	if (trString == trPageLocLeft)
 		return pageLocLeft;
-	if (trString==trPageLocMiddle)
+	if (trString == trPageLocMiddle)
 		return pageLocMiddle;
-	if (trString==trPageLocMiddleLeft)
+	if (trString == trPageLocMiddleLeft)
 		return pageLocMiddleLeft;
-	if (trString==trPageLocMiddleRight)
+	if (trString == trPageLocMiddleRight)
 		return pageLocMiddleRight;
-	if (trString==trPageLocRight)
+	if (trString == trPageLocRight)
 		return pageLocRight;
 	return trString;
 }
@@ -456,6 +471,9 @@ void CommonStrings::languageChange()
 	CommonStrings::WindowsGDI    = "Windows GDI";
 	CommonStrings::trWindowsGDI  = tr( "Windows GDI" );
 
+	//Section Name
+	CommonStrings::trSectionName = tr("Section %1");
+
 	//Units
 	CommonStrings::trStrPT = unitGetStrFromIndex(SC_PT);
 	CommonStrings::trStrMM = unitGetStrFromIndex(SC_MM);
@@ -473,20 +491,20 @@ void CommonStrings::languageChange()
 	CommonStrings::strPX = "px";
 
 	//Keyboard Modifiers
-	CommonStrings::altModifier=tr("Alt");
-	CommonStrings::shiftModifier=tr("Shift");
+	CommonStrings::altModifier = tr("Alt");
+	CommonStrings::shiftModifier = tr("Shift");
 
-#ifdef Q_OS_MAC
-	CommonStrings::controlModifier=tr("Cmd");
-	CommonStrings::metaModifier=tr("Ctrl");
+#ifdef Q_OS_MACOS
+	CommonStrings::controlModifier = tr("Cmd");
+	CommonStrings::metaModifier = tr("Ctrl");
 #endif
 #ifdef Q_OS_WIN32
-	CommonStrings::controlModifier=tr("Ctrl");
-	CommonStrings::metaModifier=tr("Windows");
+	CommonStrings::controlModifier = tr("Ctrl");
+	CommonStrings::metaModifier = tr("Windows");
 #endif
-#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
-	CommonStrings::controlModifier=tr("Ctrl");
-	CommonStrings::metaModifier=tr("Meta");
+#if !defined(Q_OS_WIN32) && !defined(Q_OS_MACOS)
+	CommonStrings::controlModifier = tr("Ctrl");
+	CommonStrings::metaModifier = tr("Meta");
 #endif
 
 }
