@@ -125,7 +125,7 @@ void ScImgDataLoader_PS::scanForFonts(const QString& fn)
 			ScTextStream ts2(&tmp, QIODevice::ReadOnly);
 			QString tmp2;
 			ts2 >> tmp2;
-			m_FontListe.removeAll(tmp2);
+			m_fontList.removeAll(tmp2);
 		}
 	}
 }
@@ -147,7 +147,7 @@ bool ScImgDataLoader_PS::parseData(const QString& fn)
 	m_isRotated = false;
 	int plateCount = 0;
 	uint startPos = 0;
-	m_FontListe.clear();
+	m_fontList.clear();
 	QFile f(fn);
 	if (f.open(QIODevice::ReadOnly))
 	{
@@ -302,7 +302,7 @@ bool ScImgDataLoader_PS::parseData(const QString& fn)
 				if (!tmp2.contains("(atend)"))
 				{
 					if (!tmp2.isEmpty())
-						m_FontListe.append(tmp2);
+						m_fontList.append(tmp2);
 					while (!ts.atEnd())
 					{
 						uint oldPos = ts.device()->pos();
@@ -317,7 +317,7 @@ bool ScImgDataLoader_PS::parseData(const QString& fn)
 						QString tmp2;
 						ts2 >> tmp2;
 						if (!tmp2.isEmpty())
-							m_FontListe.append(tmp2);
+							m_fontList.append(tmp2);
 					}
 				}
 				else
@@ -474,8 +474,8 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 	if (ext.isEmpty())
 		ext = getImageType(fn);
 
-	QString tmpFile = QDir::toNativeSeparators(ScPaths::tempFileDir() + QString("sc%1.png").arg(qMax(1, page)));
-	QString tmpFiles = QDir::toNativeSeparators(ScPaths::tempFileDir() + "sc%d.png");
+	QString tmpFile = QDir::toNativeSeparators(ScPaths::tempFileDir() + QString("sc_psld_%1.png").arg(qMax(1, page)));
+	QString tmpFiles = QDir::toNativeSeparators(ScPaths::tempFileDir() + "sc_psld_%d.png");
 	QString picFile = QDir::toNativeSeparators(fn);
 
 	float xres = gsRes;
@@ -495,19 +495,19 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 	m_CustColors.insert("Yellow", ScColor(0, 0, 255, 0));
 	m_CustColors.insert("Black", ScColor(0, 0, 0, 255));
 	found = parseData(fn);
-	if (m_FontListe.count() != 0)
+	if (m_fontList.count() != 0)
 	{
 		scanForFonts(fn);
-		if (m_FontListe.count() != 0)
+		if (m_fontList.count() != 0)
 		{
 			bool missing = false;
 			QString missingF = "";
-			for (int fo = 0; fo < m_FontListe.count(); fo++)
+			for (int fo = 0; fo < m_fontList.count(); fo++)
 			{
-				if (!PrefsManager::instance().appPrefs.fontPrefs.AvailFonts.contains(m_FontListe[fo]))
+				if (!PrefsManager::instance().appPrefs.fontPrefs.AvailFonts.contains(m_fontList[fo]))
 				{
 					missing = true;
-					missingF += m_FontListe[fo]+"\n";
+					missingF += m_fontList[fo] + "\n";
 				}
 			}
 			if (missing)
@@ -577,8 +577,8 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 				if (!m_BBoxInTrailer)
 					args.append("-dEPSCrop");
 			}
-			args.append("-r"+QString::number(gsRes));
-			args.append("-sOutputFile="+tmpFiles);
+			args.append("-r" + QString::number(gsRes));
+			args.append("-sOutputFile=" + tmpFiles);
 			args.append(picFile);
 			h = h * gsRes / 72.0;
 			int retg = callGS(args);
@@ -597,8 +597,8 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 				{
 					int wi = m_image.width();
 					int hi = m_image.height();
-					QRgb alphaFF = qRgba(255, 255, 255, 255);
-					QRgb alpha00 = qRgba(255, 255, 255,   0);
+					Q_CONSTEXPR QRgb alphaFF = qRgba(255, 255, 255, 255);
+					Q_CONSTEXPR QRgb alpha00 = qRgba(255, 255, 255,   0);
 					QRgb *s;
 					for (int yi = 0; yi < hi; ++yi)
 					{
@@ -612,9 +612,9 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 					}
 				}
 
-				QStringList files("sc*.png");
+				QStringList files("sc_psld_*.png");
 				files = QDir(ScPaths::tempFileDir()).entryList(files);
-				for (int i=0; i < files.count(); ++i)
+				for (int i = 0; i < files.count(); ++i)
 					QFile::remove(QDir::toNativeSeparators(ScPaths::tempFileDir() + files[i]));
 				
 				if (extensionIndicatesEPS(ext))
@@ -648,8 +648,8 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 			if (extensionIndicatesEPS(ext))
 				args.append("-dEPSCrop");
 			args.append("-dGrayValues=256");
-			args.append("-r"+QString::number(gsRes));
-			args.append("-sOutputFile="+tmpFiles);
+			args.append("-r" + QString::number(gsRes));
+			args.append("-sOutputFile=" + tmpFiles);
 			args.append(picFile);
 //			qDebug() << "scimgdataloader_ps:" << args;
 			int retg = callGS(args);
@@ -691,9 +691,9 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 					f.close();
 				}
 				
-				QStringList files("sc*.png");
+				QStringList files("sc_psld_*.png");
 				files = QDir(ScPaths::tempFileDir()).entryList(files);
-				for (int i=0; i < files.count(); ++i)
+				for (int i = 0; i < files.count(); ++i)
 					QFile::remove(QDir::toNativeSeparators(ScPaths::tempFileDir() + files[i]));
 				
 				if (extensionIndicatesEPS(ext))
@@ -798,8 +798,8 @@ void ScImgDataLoader_PS::loadPhotoshop(const QString& fn, int gsRes)
 			{
 				int wi = m_image.width();
 				int hi = m_image.height();
-				QRgb alphaFF = qRgba(255,255,255,255);
-				QRgb alpha00 = qRgba(255,255,255,  0);
+				Q_CONSTEXPR QRgb alphaFF = qRgba(255,255,255,255);
+				Q_CONSTEXPR QRgb alpha00 = qRgba(255,255,255,  0);
 				QRgb *s;
 				for (int yi = 0; yi < hi; ++yi)
 				{
@@ -958,11 +958,11 @@ bool ScImgDataLoader_PS::loadPSjpeg(const QString& fn)
 		{
 			uchar *in;
 			QRgb *out;
-			for (uint j=0; j<cinfo.output_height; j++)
+			for (uint j = 0; j < cinfo.output_height; j++)
 			{
 				in = m_image.scanLine(j) + cinfo.output_width * 3;
 				out = (QRgb*) m_image.scanLine(j);
-				for (uint i=cinfo.output_width; i--; )
+				for (uint i = cinfo.output_width; i--; )
 				{
 					in -= 3;
 					out[i] = qRgb(in[0], in[1], in[2]);
@@ -1084,11 +1084,11 @@ bool ScImgDataLoader_PS::loadPSjpeg(const QString& fn, QImage &tmpImg)
 		{
 			uchar *in;
 			QRgb *out;
-			for (uint j=0; j<cinfo.output_height; j++)
+			for (uint j = 0; j < cinfo.output_height; j++)
 			{
 				in = tmpImg.scanLine(j) + cinfo.output_width * 3;
 				out = (QRgb*) tmpImg.scanLine(j);
-				for (uint i=cinfo.output_width; i--; )
+				for (uint i = cinfo.output_width; i--; )
 				{
 					in -= 3;
 					out[i] = qRgb(in[0], in[1], in[2]);
@@ -1548,7 +1548,7 @@ void ScImgDataLoader_PS::loadDCS1(const QString& fn, int gsRes)
 	yres = gsRes;
 	m_image = QImage( qRound(b * gsRes / 72.0), qRound(h * gsRes / 72.0), QImage::Format_ARGB32 );
 	m_image.fill(qRgba(0, 0, 0, 0));
-	bool isEncapPS=extensionIndicatesEPS(ext);
+	bool isEncapPS = extensionIndicatesEPS(ext);
 	if (isEncapPS)
 		args.append("-dEPSCrop");
 	args.append("-r"+QString::number(gsRes));
@@ -1672,8 +1672,8 @@ bool ScImgDataLoader_PS::preloadAlphaChannel(const QString& fn, int page, int gs
 	if (!fi.exists())
 		return false;
 	QString ext = fi.suffix().toLower();
-	QString tmpFile = QDir::toNativeSeparators(ScPaths::tempFileDir() + QString("sc%1.png").arg(qMax(1, page)));
-	QString tmpFiles = QDir::toNativeSeparators(ScPaths::tempFileDir() + "sc%d.png");
+	QString tmpFile = QDir::toNativeSeparators(ScPaths::tempFileDir() + QString("sc_psld_%1.png").arg(qMax(1, page)));
+	QString tmpFiles = QDir::toNativeSeparators(ScPaths::tempFileDir() + "sc_psld_%d.png");
 	QString picFile = QDir::toNativeSeparators(fn);
 	double x, y, b, h;
 	bool found = false;
@@ -1691,8 +1691,8 @@ bool ScImgDataLoader_PS::preloadAlphaChannel(const QString& fn, int page, int gs
 			if (!m_BBoxInTrailer)
 				args.append("-dEPSCrop");
 		}
-		args.append("-r"+QString::number(gsRes));
-		args.append("-sOutputFile="+tmpFiles);
+		args.append("-r" + QString::number(gsRes));
+		args.append("-sOutputFile=" + tmpFiles);
 		args.append(picFile);
 //		qDebug() << "scimgdataloader_ps(alpha):" << args;
 		int retg = callGS(args);
@@ -1711,8 +1711,8 @@ bool ScImgDataLoader_PS::preloadAlphaChannel(const QString& fn, int page, int gs
 			{
 				int wi = m_image.width();
 				int hi = m_image.height();
-				QRgb alphaFF = qRgba(255,255,255,255);
-				QRgb alpha00 = qRgba(255,255,255,  0);
+				Q_CONSTEXPR QRgb alphaFF = qRgba(255,255,255,255);
+				Q_CONSTEXPR QRgb alpha00 = qRgba(255,255,255,  0);
 				QRgb *s;
 				for (int yi = 0; yi < hi; ++yi)
 				{
@@ -1726,9 +1726,9 @@ bool ScImgDataLoader_PS::preloadAlphaChannel(const QString& fn, int page, int gs
 				}
 			}
 			
-			QStringList files("sc*.png");
+			QStringList files("sc_psld_*.png");
 			files = QDir(ScPaths::tempFileDir()).entryList(files);
-			for (int i=0; i < files.count(); ++i)
+			for (int i = 0; i < files.count(); ++i)
 				QFile::remove(QDir::toNativeSeparators(ScPaths::tempFileDir() + files[i]));
 
 			hasAlpha = true;
