@@ -19,7 +19,10 @@ PyObject *scribus_getcelltext(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -28,12 +31,12 @@ PyObject *scribus_getcelltext(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell text on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell text on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 
@@ -62,7 +65,11 @@ PyObject *scribus_setcelltext(PyObject* /* self */, PyObject* args)
 	PyESString text;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "iies|es", &row, &column, "utf-8", text.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		text.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -71,12 +78,12 @@ PyObject *scribus_setcelltext(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell text on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell text on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setText(QString::fromUtf8(text.c_str()));
@@ -88,7 +95,10 @@ PyObject *scribus_getcellstyle(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -97,12 +107,12 @@ PyObject *scribus_getcellstyle(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell style on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell style on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	return PyUnicode_FromString(table->cellAt(row, column).styleName().toUtf8());
@@ -114,7 +124,11 @@ PyObject *scribus_setcellstyle(PyObject* /* self */, PyObject* args)
 	PyESString style;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "iies|es", &row, &column, "utf-8", style.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		style.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -123,12 +137,12 @@ PyObject *scribus_setcellstyle(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell style on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell style on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setStyle(QString::fromUtf8(style.c_str()));
@@ -140,7 +154,10 @@ PyObject *scribus_getcellrowspan(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -149,7 +166,7 @@ PyObject *scribus_getcellrowspan(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell row span from non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell row span from non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	return PyLong_FromLong(static_cast<long>(table->cellAt(row, column).rowSpan()));
@@ -160,7 +177,10 @@ PyObject *scribus_getcellcolumnspan(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -169,7 +189,7 @@ PyObject *scribus_getcellcolumnspan(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell column span from non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell column span from non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	return PyLong_FromLong(static_cast<long>(table->cellAt(row, column).columnSpan()));
@@ -180,7 +200,10 @@ PyObject *scribus_getcellfillcolor(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -189,12 +212,12 @@ PyObject *scribus_getcellfillcolor(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell fill color on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get cell fill color on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	return PyUnicode_FromString(table->cellAt(row, column).fillColor().toUtf8());
@@ -206,7 +229,11 @@ PyObject *scribus_setcellfillcolor(PyObject* /* self */, PyObject* args)
 	PyESString color;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "iies|es", &row, &column, "utf-8", color.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		color.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -215,12 +242,12 @@ PyObject *scribus_setcellfillcolor(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell fill color on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell fill color on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setFillColor(QString::fromUtf8(color.c_str()));
@@ -233,7 +260,10 @@ PyObject *scribus_setcellleftborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -242,12 +272,12 @@ PyObject *scribus_setcellleftborder(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell left border on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell left border on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 
@@ -267,7 +297,10 @@ PyObject *scribus_setcellrightborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -276,12 +309,12 @@ PyObject *scribus_setcellrightborder(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell right border on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell right border on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 
@@ -301,7 +334,10 @@ PyObject *scribus_setcelltopborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -310,12 +346,12 @@ PyObject *scribus_setcelltopborder(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell top border on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell top border on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 
@@ -335,7 +371,10 @@ PyObject *scribus_setcellbottomborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -344,12 +383,12 @@ PyObject *scribus_setcellbottomborder(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell bottom border on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell bottom border on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 
@@ -369,7 +408,10 @@ PyObject *scribus_setcellleftpadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -378,17 +420,17 @@ PyObject *scribus_setcellleftpadding(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell left padding on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell left padding on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	if (padding < 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setLeftPadding(padding);
@@ -402,7 +444,10 @@ PyObject *scribus_setcellrightpadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -411,17 +456,17 @@ PyObject *scribus_setcellrightpadding(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell right padding on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell right padding on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	if (padding < 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setRightPadding(padding);
@@ -435,7 +480,10 @@ PyObject *scribus_setcelltoppadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -444,17 +492,17 @@ PyObject *scribus_setcelltoppadding(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell top padding on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell top padding on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	if (padding < 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setTopPadding(padding);
@@ -468,7 +516,10 @@ PyObject *scribus_setcellbottompadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -477,17 +528,17 @@ PyObject *scribus_setcellbottompadding(PyObject* /* self */, PyObject* args)
 	const PageItem_Table *table = i->asTable();
 	if (!table)
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell bottom padding on a non-table item.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set cell bottom padding on a non-table item.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (column < 0 || column >= table->columns() || row < 0 || row >= table->rows())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("The cell %1,%2 does not exist in table", "python error").arg(row).arg(column).toUtf8().constData());
 		return nullptr;
 	}
 	if (padding < 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cell padding must be >= 0.0", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	table->cellAt(row, column).setBottomPadding(padding);
