@@ -47,7 +47,7 @@ PyObject *scribus_newdocument(PyObject* /* self */, PyObject* args)
 	// checking the bounds
 	if (pagesType < firstPageOrder)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("firstPageOrder is bigger than allowed.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("firstPageOrder is bigger than allowed.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -229,11 +229,14 @@ PyObject *scribus_opendoc(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	bool ret = ScCore->primaryMainWindow()->loadDoc(QString::fromUtf8(name.c_str()));
 	if (!ret)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Failed to open document: %1","python error").arg(name.c_str()).toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Failed to open document: %1","python error").arg(name.c_str()).toUtf8().constData());
 		return nullptr;
 	}
 	return PyBool_FromLong(static_cast<long>(true));
@@ -273,13 +276,16 @@ PyObject *scribus_savedocas(PyObject* /* self */, PyObject* args)
 {
 	PyESString fileName;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", fileName.ptr()))
+	{
+		fileName.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	bool ret = ScCore->primaryMainWindow()->DoFileSave(QString::fromUtf8(fileName.c_str()));
 	if (!ret)
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Failed to save document.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Failed to save document.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	return PyBool_FromLong(static_cast<long>(true));
@@ -334,7 +340,7 @@ PyObject *scribus_setunit(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if ((e < UNITMIN) || (e > UNITMAX))
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Unit out of range. Use one of the scribus.UNIT_* constants.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Unit out of range. Use one of the scribus.UNIT_* constants.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	ScCore->primaryMainWindow()->slotChangeUnit(e);
@@ -375,7 +381,10 @@ PyObject *scribus_stringvaluetopoints(PyObject* /* self */, PyObject *args)
 {
     PyESString strValue;
     if (!PyArg_ParseTuple(args, "es", "utf-8", strValue.ptr()))
-        return nullptr;
+	{
+		strValue.resetDontFree();
+		return nullptr;
+	}
 
     QString qv = QString::fromUtf8(strValue.c_str());
 
@@ -390,7 +399,10 @@ PyObject *scribus_loadstylesfromfile(PyObject* /* self */, PyObject *args)
 {
 	PyESString fileName;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", fileName.ptr()))
+	{
+		fileName.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	ScCore->primaryMainWindow()->doc->loadStylesFromFile(QString::fromUtf8(fileName.c_str()));
@@ -450,7 +462,10 @@ PyObject *scribus_editmasterpage(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const QString masterPageName(name.c_str());
@@ -470,7 +485,10 @@ PyObject* scribus_createmasterpage(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const QString masterPageName(name.c_str());
@@ -490,7 +508,10 @@ PyObject* scribus_deletemasterpage(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const QString masterPageName(name.c_str());
@@ -526,7 +547,7 @@ PyObject *scribus_getmasterpage(PyObject* /* self */, PyObject* args)
 	const ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	if ((e < 0) || (e > currentDoc->Pages->count() - 1))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range: '%1'.","python error").arg(e+1).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range: '%1'.","python error").arg(e+1).toUtf8().constData());
 		return nullptr;
 	}
 	return PyUnicode_FromString(currentDoc->DocPages.at(e)->masterPageName().toUtf8());
@@ -537,7 +558,10 @@ PyObject* scribus_applymasterpage(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int page = 0;
 	if (!PyArg_ParseTuple(args, "esi", "utf-8", name.ptr(), &page))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const QString masterPageName(name.c_str());
@@ -545,18 +569,18 @@ PyObject* scribus_applymasterpage(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	if (!currentDoc->MasterNames.contains(masterPageName))
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Master page does not exist: '%1'","python error").arg(masterPageName).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Master page does not exist: '%1'","python error").arg(masterPageName).toUtf8().constData());
 		return nullptr;
 	}
 	if ((page < 1) || (page > currentDoc->Pages->count()))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range: %1.","python error").arg(page).toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range: %1.","python error").arg(page).toUtf8().constData());
 		return nullptr;
 	}
 
 	if (!currentDoc->applyMasterPage(masterPageName, page-1))
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Failed to apply masterpage '%1' on page: %2","python error").arg(masterPageName).arg(page).toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Failed to apply masterpage '%1' on page: %2","python error").arg(masterPageName).arg(page).toUtf8().constData());
 		return nullptr;
 	}
 	Py_RETURN_NONE;
