@@ -22,7 +22,11 @@ PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	PyESString image;
 	if (!PyArg_ParseTuple(args, "es|es", "utf-8", image.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		image.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -30,7 +34,7 @@ PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	ScCore->primaryMainWindow()->doc->loadPict(QString::fromUtf8(image.c_str()), item);
@@ -42,7 +46,10 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -50,7 +57,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -58,7 +65,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = (tempSelection.count() != 0);
+	bool hadOrigSelection = !tempSelection.isEmpty();
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -84,7 +91,10 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -92,7 +102,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -100,7 +110,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = (tempSelection.count() != 0);
+	bool hadOrigSelection = !tempSelection.isEmpty();
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -127,7 +137,10 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -135,7 +148,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -143,7 +156,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*ScCore->primaryMainWindow()->doc->m_Selection);
-	bool hadOrigSelection = (tempSelection.count() != 0);
+	bool hadOrigSelection = !tempSelection.isEmpty();
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -171,7 +184,10 @@ PyObject *scribus_setimagebrightness(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double n;
 	if (!PyArg_ParseTuple(args, "d|es", &n, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -179,7 +195,7 @@ PyObject *scribus_setimagebrightness(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -199,7 +215,10 @@ PyObject *scribus_setimagegrayscale(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -207,7 +226,7 @@ PyObject *scribus_setimagegrayscale(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -226,7 +245,10 @@ PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -237,7 +259,7 @@ PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = (tempSelection.count() != 0);
+	bool hadOrigSelection = !tempSelection.isEmpty();
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -268,7 +290,10 @@ PyObject *scribus_moveobjectabs(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -279,7 +304,7 @@ PyObject *scribus_moveobjectabs(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = (tempSelection.count() != 0);
+	bool hadOrigSelection = !tempSelection.isEmpty();
 
 	// Clear the selection
 	currentView->deselectItems();
@@ -310,7 +335,10 @@ PyObject *scribus_rotateobjectrel(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x;
 	if (!PyArg_ParseTuple(args, "d|es", &x, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -331,7 +359,12 @@ PyObject *scribus_setrotation(PyObject* /* self */, PyObject* args, PyObject* kw
 					  const_cast<char *>("basepoint"),
 					  nullptr};
 	if (!PyArg_ParseTupleAndKeywords(args, kw, "d|esi", kwargs, &rotation, "utf-8", name.ptr(), &basepoint))
+	{
+		// Some old python versions leave bad pointers behind when an argument parsing error occurs
+		// so we can't free the memory safely in this case
+		name.resetDontFree();
 		return nullptr;
+	}
 
 	if (!checkHaveDocument())
 		return nullptr;
@@ -361,7 +394,10 @@ PyObject *scribus_sizeobject(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -380,7 +416,7 @@ PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (il == nullptr && ScCore->primaryMainWindow()->doc->m_Selection->count() < 2)
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("Need selection or argument list of items to group", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("Need selection or argument list of items to group", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	Selection *tempSelection = nullptr;
@@ -389,9 +425,9 @@ PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 	// If we were passed a list of items to group...
 	if (il != nullptr)
 	{
-		int len = PyList_Size(il);
+		Py_ssize_t len = PyList_Size(il);
 		tempSelection = new Selection(ScCore->primaryMainWindow(), false);
-		for (int i = 0; i < len; i++)
+		for (Py_ssize_t i = 0; i < len; i++)
 		{
 			// FIXME: We might need to explicitly get this string as utf8
 			// but as sysdefaultencoding is utf8 it should be a no-op to do
@@ -412,7 +448,7 @@ PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 	if (finalSelection->count() < 2)
 	{
 		// We can't very well group only one item
-		PyErr_SetString(NoValidObjectError, QObject::tr("Cannot group less than two items", "python error").toLocal8Bit().constData());
+		PyErr_SetString(NoValidObjectError, QObject::tr("Cannot group less than two items", "python error").toUtf8().constData());
 		finalSelection = nullptr;
 		delete tempSelection;
 		return nullptr;
@@ -429,7 +465,10 @@ PyObject *scribus_ungroupobjects(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -449,12 +488,15 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double sc;
 	if (!PyArg_ParseTuple(args, "d|es", &sc, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	if (sc == 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot scale by 0%.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot scale by 0%.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -466,12 +508,10 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 
 	currentView->deselectItems();
 	currentView->selectItem(i);
-//	int h = currentView->frameResizeHandle;
-//	currentView->frameResizeHandle = 1;
 	currentView->startGroupTransaction(Um::Resize, "", Um::IResize);
 	currentDoc->scaleGroup(sc, sc);
 	currentView->endGroupTransaction();
-//	currentView->frameResizeHandle = h;
+
 	Py_RETURN_NONE;
 }
 
@@ -485,7 +525,12 @@ PyObject *scribus_getGroupItems(PyObject * /*self*/, PyObject* args, PyObject* k
 	unsigned int type = 0;
 	char* kwargs[] = {const_cast<char*>("name"), const_cast<char*>("recursive"), const_cast<char*>("type"), nullptr};
 	if (!PyArg_ParseTupleAndKeywords(args, kw, "|espi", kwargs, "utf-8", name.ptr(), &recursive, &type))
+	{
+		// Some old python versions leave bad pointers behind when an argument parsing error occurs
+		// so we can't free the memory safely in this case
+		name.resetDontFree();
 		return nullptr;
+	}
 
 	PageItem *pageItem = GetUniqueItem(QString::fromUtf8(name.c_str()));
 	if (pageItem == nullptr)
@@ -546,7 +591,10 @@ PyObject *scribus_selectobject(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -568,7 +616,10 @@ PyObject *scribus_lockobject(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -586,7 +637,10 @@ PyObject *scribus_islocked(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -603,13 +657,16 @@ PyObject *scribus_setscaleframetoimage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
 	if (item == nullptr)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	Selection *sel = new Selection(ScCore->primaryMainWindow());
@@ -628,7 +685,12 @@ PyObject *scribus_setscaleimagetoframe(PyObject* /* self */, PyObject* args, PyO
 	char* kwargs[] = {const_cast<char*>("scaletoframe"),
 		const_cast<char*>("proportional"), const_cast<char*>("name"), nullptr};
 	if (!PyArg_ParseTupleAndKeywords(args, kw, "i|ies", kwargs, &scaleToFrame, &proportional, "utf-8", name.ptr()))
+	{
+		// Some old python versions leave bad pointers behind when an argument parsing error occurs
+		// so we can't free the memory safely in this case
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -636,7 +698,7 @@ PyObject *scribus_setscaleimagetoframe(PyObject* /* self */, PyObject* args, PyO
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	// Set the item to scale if appropriate. ScaleType 1 is free
@@ -657,7 +719,10 @@ PyObject *scribus_flipobject(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double h, v;
 	if (!PyArg_ParseTuple(args, "dd|es", &h, &v, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -668,7 +733,7 @@ PyObject *scribus_flipobject(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = (tempSelection.count() != 0);
+	bool hadOrigSelection = !tempSelection.isEmpty();
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -705,7 +770,7 @@ PyObject *scribus_combinepolygons(PyObject * /* self */)
 		const PageItem* it = currentDoc->m_Selection->itemAt(i);
 		if (!it->isPolygon() && !it->isPolyLine())
 		{
-			PyErr_SetString(WrongFrameTypeError, QObject::tr("Selection must contain only shapes or bezier curves.", "python error").toLocal8Bit().constData());
+			PyErr_SetString(WrongFrameTypeError, QObject::tr("Selection must contain only shapes or bezier curves.", "python error").toUtf8().constData());
 			return nullptr;
 		}
 	}
@@ -724,14 +789,14 @@ PyObject *scribus_seteditmode(PyObject * /* self */)
 
 	if (currentDoc->m_Selection->count() < 1)
 	{
-		PyErr_SetString(NoValidObjectError, QString("No item selected.").toLocal8Bit().constData());
+		PyErr_SetString(NoValidObjectError, QString("No item selected.").toUtf8().constData());
 		return nullptr;
 	}
 
 	auto currItem = currentDoc->m_Selection->itemAt(0);
 	if (!currItem->isTextFrame() && !currItem->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -749,14 +814,14 @@ PyObject *scribus_setnormalmode(PyObject * /* self */)
 
 	if (currentDoc->m_Selection->count() < 1)
 	{
-		PyErr_SetString(NoValidObjectError, QString("No item selected.").toLocal8Bit().constData());
+		PyErr_SetString(NoValidObjectError, QString("No item selected.").toUtf8().constData());
 		return nullptr;
 	}
 
 	auto currItem = currentDoc->m_Selection->itemAt(0);
 	if (!currItem->isTextFrame() && !currItem->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toUtf8().constData());
 		return nullptr;
 	}
 
