@@ -60,6 +60,22 @@ selected item is used.\n\
 /*! Rotate ABS the object */
 PyObject *scribus_rotateobjectabs(PyObject * /*self*/, PyObject* args);
 
+PyDoc_STRVAR(scribus_setrotation__doc__,
+QT_TR_NOOP("setRotation(rotation [, name=\"\", basepoint=None])\n\
+\n\
+Sets the rotation of the object \"name\" to \"rotation\". Positive values\n\
+ mean counter clockwise rotation. If \"name\" is not given the currently\n\
+ selected item is used.\n\
+\n\
+If basepoint is not set, the current basepoint is used.\n\
+Valid values for basepoint are:\n\
+BASEPOINT_TOPLEFT, BASEPOINT_TOP, BASEPOINT_TOPRIGHT,\n\
+BASEPOINT_LEFT, BASEPOINT_CENTER, BASEPOINT_RIGHT,\n\
+BASEPOINT_BOTTOMLEFT, BASEPOINT_BOTTOM, BASEPOINT_BOTTOMRIGHT\n\
+ "));
+/*! Set the rotation of the object */
+PyObject *scribus_setrotation(PyObject * /*self*/, PyObject* args, PyObject* kw);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_sizeobject__doc__,
 QT_TR_NOOP("sizeObject(width, height [, \"name\"])\n\
@@ -94,7 +110,13 @@ PyObject *scribus_selectioncount(PyObject * /*self*/);
 PyDoc_STRVAR(scribus_selectobject__doc__,
 QT_TR_NOOP("selectObject(\"name\")\n\
 \n\
-Selects the object with the given \"name\".\n\
+Adds the object with the given \"name\" to the current selection.\n\
+\n\
+Lots of scripter function use the concept of \"currently selected item\" if an object name\n\
+is not provided. In the case of multiple selections, the currently selected item is always\n\
+the first item in the selection. As a consequence if you are planning to use object \"name\"\n\
+as the currently selected item for following operations and current selection is not empty,\n\
+you will have to call deselectAll() before calling this function.\n\
 "));
 /*! Count selection */
 PyObject *scribus_selectobject(PyObject * /*self*/, PyObject* args);
@@ -142,6 +164,24 @@ May raise ValueError if an invalid scale factor is passed.\n\
 /*! Scale group with object name */
 PyObject *scribus_scalegroup(PyObject * /*self*/, PyObject* args);
 
+/*! docstring */
+PyDoc_STRVAR(scribus_getGroupItems__doc__,
+QT_TR_NOOP("getGroupItems([\"name\", recursive=False, type=0]) -> list\n\n\
+Return the list of items in the group.\n\
+\n\
+`recursive`: if True and some of the items are groups, also include their items (recursively).\n\
+`type`: if not 0, only retain items of this type.\n\
+\n\
+Each item is defined as a tuple containing:\n\
+`(name : str, objectType : int, order : int)`\n\
+E.g. [('Text1', 4, 0), ('Image1', 2, 1)]\n\
+means that object named 'Text1' is a text frame (type 4) and is the first at\n\
+the page...\n\
+\n\
+If \"name\" is not given the currently selected item is used."));
+/*! List the items in a group. */
+PyObject *scribus_getGroupItems(PyObject * /*self*/, PyObject* args, PyObject* kw);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_loadimage__doc__,
 QT_TR_NOOP("loadImage(\"filename\" [, \"name\"])\n\
@@ -278,4 +318,18 @@ Combine two or more selected Polygons\n\
 "));
 PyObject *scribus_combinepolygons(PyObject * /* self */);
 
+PyDoc_STRVAR(scribus_seteditmode__doc__,
+QT_TR_NOOP("setEditMode()\n\
+\n\
+Start the edit mode for the current item.\n\
+"));
+PyObject *scribus_seteditmode(PyObject * /*self*/);
+
+PyDoc_STRVAR(scribus_setnormalmode__doc__,
+QT_TR_NOOP("setNormalMode()\n\
+\n\
+Set the current item in normal mode (out of edit mode).\n\
+"));
+PyObject *scribus_setnormalmode(PyObject * /*self*/);
+
 #endif
