@@ -24,7 +24,10 @@ PyObject *scribus_createrect(PyObject* /* self */, PyObject* args)
 	PyESString name;
 
 	if (!PyArg_ParseTuple(args, "dddd|es", &x, &y, &w, &h, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 //	if (ItemExists(QString::fromUtf8(name.c_str())))
@@ -54,7 +57,10 @@ PyObject *scribus_createellipse(PyObject* /* self */, PyObject* args)
 	double x, y, w, h;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "dddd|es", &x, &y, &w, &h, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	int i = ScCore->primaryMainWindow()->doc->itemAdd(PageItem::Polygon, PageItem::Ellipse,
@@ -80,7 +86,10 @@ PyObject *scribus_createimage(PyObject* /* self */, PyObject* args)
 	double x, y, w, h;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "dddd|es", &x, &y, &w, &h, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	int i = ScCore->primaryMainWindow()->doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified,
@@ -105,7 +114,10 @@ PyObject *scribus_createtext(PyObject* /* self */, PyObject* args)
 	double x, y, w, h;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "dddd|es", &x, &y, &w, &h, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	int i = ScCore->primaryMainWindow()->doc->itemAdd(PageItem::TextFrame, PageItem::Unspecified,
@@ -130,12 +142,15 @@ PyObject *scribus_createtable(PyObject* /* self */, PyObject* args)
 	int numRows, numColumns;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "ddddii|es", &x, &y, &w, &h, &numRows, &numColumns, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	if (numRows < 1 || numColumns < 1)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Both numRows and numColumns must be greater than 0.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Both numRows and numColumns must be greater than 0.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	int i = ScCore->primaryMainWindow()->doc->itemAdd(PageItem::Table, PageItem::Unspecified,
@@ -165,7 +180,10 @@ PyObject *scribus_createline(PyObject* /* self */, PyObject* args)
 	double x, y, w, h;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "dddd|es", &x, &y, &w, &h, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	x = pageUnitXToDocX(x);
@@ -227,23 +245,26 @@ PyObject *scribus_createpolyline(PyObject* /* self */, PyObject* args)
 	PyObject *il;
 	// FIXME: PyList_Check failing will cause the function to return nullptr w/o an exception. Separarate out the check.
 	if ((!PyArg_ParseTuple(args, "O|es", &il, "utf-8", name.ptr())) || (!PyList_Check(il)))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	Py_ssize_t len = PyList_Size(il);
 	if (len < 4)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain at least two points (four values).","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain at least two points (four values).","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if ((len % 2) != 0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain an even number of values.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain an even number of values.","python error").toUtf8().constData());
 		return nullptr;
 	}
 //	if (ItemExists(QString::fromUtf8(name.c_str())))
 //	{
-//		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error").toLocal8Bit().constData());
+//		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error").toUtf8().constData());
 //		return nullptr;
 //	}
 	double x, y, w, h;
@@ -304,23 +325,26 @@ PyObject *scribus_createpolygon(PyObject* /* self */, PyObject* args)
 	PyObject *il;
 	// FIXME: PyList_Check failing will cause the function to return nullptr w/o an exception. Separarate out the check.
 	if ((!PyArg_ParseTuple(args, "O|es", &il, "utf-8", name.ptr())) || (!PyList_Check(il)))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	Py_ssize_t len = PyList_Size(il);
 	if (len < 6)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain at least three points (six values).","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain at least three points (six values).","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if ((len % 2) != 0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain an even number of values.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain an even number of values.","python error").toUtf8().constData());
 		return nullptr;
 	}
 //	if (ItemExists(QString::fromUtf8(name.c_str())))
 //	{
-//		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error").toLocal8Bit().constData());
+//		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error").toUtf8().constData());
 //		return nullptr;
 //	}
 	double x, y, w, h;
@@ -385,23 +409,26 @@ PyObject *scribus_createbezierline(PyObject* /* self */, PyObject* args)
 	PyObject *il;
 	// FIXME: PyList_Check failing will cause the function to return nullptr w/o an exception. Separarate out the check.
 	if ((!PyArg_ParseTuple(args, "O|es", &il, "utf-8", name.ptr())) || (!PyList_Check(il)))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	Py_ssize_t len = PyList_Size(il);
 	if (len < 8)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain at least four points (eight values).","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must contain at least four points (eight values).","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if ((len % 6) != 0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must have a multiple of six values.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Point list must have a multiple of six values.","python error").toUtf8().constData());
 		return nullptr;
 	}
 //	if (ItemExists(QString::fromUtf8(name.c_str())))
 //	{
-//		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error").toLocal8Bit().constData());
+//		PyErr_SetString(NameExistsError, QObject::tr("An object with the requested name already exists.","python error").toUtf8().constData());
 //		return nullptr;
 //	}
 	double x, y, w, h, kx, ky, kx2, ky2;
@@ -480,7 +507,12 @@ PyObject *scribus_createpathtext(PyObject* /* self */, PyObject* args)
 	PyESString textB;
 	PyESString polyB;
 	if (!PyArg_ParseTuple(args, "ddeses|es", &x, &y, "utf-8", textB.ptr(), "utf-8", polyB.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		textB.resetDontFree();
+		polyB.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 //	if (ItemExists(QString::fromUtf8(name.c_str())))
@@ -494,7 +526,7 @@ PyObject *scribus_createpathtext(PyObject* /* self */, PyObject* args)
 	PageItem *ii = GetItem(QString::fromUtf8(polyB.c_str()));
 	if ((i == nullptr) || (ii == nullptr))
 	{
-		PyErr_SetString(NotFoundError, QObject::tr("Object not found.","python error").toLocal8Bit().constData());
+		PyErr_SetString(NotFoundError, QObject::tr("Object not found.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	ScCore->primaryMainWindow()->doc->m_Selection->clear();
@@ -518,7 +550,10 @@ PyObject *scribus_deleteobject(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -535,7 +570,10 @@ PyObject *scribus_gettextflowmode(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -553,7 +591,10 @@ PyObject *scribus_settextflowmode(PyObject* /* self */, PyObject* args)
 	int state = -1;
 
 	if (!PyArg_ParseTuple(args, "es|i", "utf-8", name.ptr(), &state))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -585,7 +626,10 @@ PyObject *scribus_objectexists(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	if (ItemExists(QString::fromUtf8(name.c_str())))
@@ -597,7 +641,10 @@ PyObject *scribus_getcharacterstyle(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -605,7 +652,7 @@ PyObject *scribus_getcharacterstyle(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if ((item->itemType() != PageItem::TextFrame) && (item->itemType() != PageItem::PathText))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get character style of a non-text frame.", "python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get character style of a non-text frame.", "python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -637,7 +684,10 @@ PyObject *scribus_getparagraphstyle(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -645,7 +695,7 @@ PyObject *scribus_getparagraphstyle(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if ((item->itemType() != PageItem::TextFrame) && (item->itemType() != PageItem::PathText))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get style of a non-text frame.", "python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get style of a non-text frame.", "python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -681,7 +731,11 @@ PyObject *scribus_setparagraphstyle(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	PyESString style;
 	if (!PyArg_ParseTuple(args, "es|es", "utf-8", style.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		style.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -689,7 +743,7 @@ PyObject *scribus_setparagraphstyle(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if ((item->itemType() != PageItem::TextFrame) && (item->itemType() != PageItem::PathText))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set style on a non-text frame.", "python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set style on a non-text frame.", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	
@@ -703,7 +757,7 @@ PyObject *scribus_setparagraphstyle(PyObject* /* self */, PyObject* args)
 	{
 		// whoops, the user specified an invalid style, complain loudly.
 		// FIXME: Should use a more specific exception.
-		PyErr_SetString(NotFoundError, QObject::tr("Style not found.","python error").toLocal8Bit().constData());
+		PyErr_SetString(NotFoundError, QObject::tr("Style not found.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -757,7 +811,11 @@ PyObject *scribus_setcharstyle(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	PyESString style;
 	if (!PyArg_ParseTuple(args, "es|es", "utf-8", style.ptr(), "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
+		style.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -765,7 +823,7 @@ PyObject *scribus_setcharstyle(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if ((item->itemType() != PageItem::TextFrame) && (item->itemType() != PageItem::PathText))
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set character style on a non-text frame.", "python error").toLocal8Bit().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot set character style on a non-text frame.", "python error").toUtf8().constData());
 		return nullptr;
 	}
 	
@@ -779,7 +837,7 @@ PyObject *scribus_setcharstyle(PyObject* /* self */, PyObject* args)
 	{
 		// whoops, the user specified an invalid style, complain loudly.
 		// FIXME: Should use a more specific exception.
-		PyErr_SetString(NotFoundError, QObject::tr("Character style not found.", "python error").toLocal8Bit().constData());
+		PyErr_SetString(NotFoundError, QObject::tr("Character style not found.", "python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -828,7 +886,10 @@ PyObject *scribus_duplicateobject(PyObject * /* self */, PyObject *args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 
@@ -862,7 +923,7 @@ PyObject *scribus_duplicateobjects(PyObject * /* self */, PyObject *args)
 
 	if ((pyObject != nullptr) && !PyUnicode_Check(pyObject) && !PyList_Check(pyObject))
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a string or a list of strings", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a string or a list of strings", "python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -884,7 +945,7 @@ PyObject *scribus_duplicateobjects(PyObject * /* self */, PyObject *args)
 			PyObject* pyItem = PyList_GetItem(pyObject, i);
 			if (!PyUnicode_Check(pyItem))
 			{
-				PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a list of strings", "python error").toLocal8Bit().constData());
+				PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a list of strings", "python error").toUtf8().constData());
 				return nullptr;
 			}
 			const char* name = PyUnicode_AsUTF8(pyItem);
@@ -936,7 +997,10 @@ PyObject *scribus_copyobject(PyObject * /* self */, PyObject *args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 
@@ -970,7 +1034,7 @@ PyObject *scribus_copyobjects(PyObject * /* self */, PyObject *args)
 
 	if ((pyObject != nullptr) && !PyUnicode_Check(pyObject) && !PyList_Check(pyObject))
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a string or a list of strings", "python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a string or a list of strings", "python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -992,7 +1056,7 @@ PyObject *scribus_copyobjects(PyObject * /* self */, PyObject *args)
 			PyObject* pyItem = PyList_GetItem(pyObject, i);
 			if (!PyUnicode_Check(pyItem))
 			{
-				PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a list of strings", "python error").toLocal8Bit().constData());
+				PyErr_SetString(PyExc_TypeError, QObject::tr("incorrect argument: must be a list of strings", "python error").toUtf8().constData());
 				return nullptr;
 			}
 			const char* name = PyUnicode_AsUTF8(pyItem);
@@ -1075,7 +1139,10 @@ PyObject *scribus_getitempagenumber(PyObject *, PyObject *args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 
