@@ -54,24 +54,31 @@ PyObject *scribus_createparagraphstyle(PyObject* /* self */, PyObject* args, PyO
 		&leftMargin, &rightMargin, &gapBefore, &gapAfter, &firstIndent,
 		&hasDropCap, &dropCapLines, &peOffset, "utf-8", charStyle.ptr(),
 		"utf-8", bullet.ptr(), &tabDefinitions))
+	{
+		// Some old python versions leave bad pointers behind when an argument parsing error occurs
+		// so we can't free the memory safely in this case
+		name.resetDontFree();
+		charStyle.resetDontFree();
+		bullet.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	if (name.isEmpty())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty paragraph style name.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty paragraph style name.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	
 	if ((hasDropCap != 0) && (dropCapLines <= 1) )
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap is true but dropcaplines value is invalid","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap is true but dropcaplines value is invalid","python error").toUtf8().constData());
 		return nullptr;
 	}
 	
 	if (bullet.length() > 0 && (hasDropCap  != 0))
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap and bullet are not allowed to be specified together.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap and bullet are not allowed to be specified together.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -125,7 +132,7 @@ PyObject *scribus_createparagraphstyle(PyObject* /* self */, PyObject* args, PyO
 			float tabPosition = 0.0;
 			if (!PyArg_Parse(tabPositionDefinition, "f", &tabPosition))
 			{
-				PyErr_SetString(PyExc_TypeError, QObject::tr("invalid tab-position specified.","python error").toLocal8Bit().constData());
+				PyErr_SetString(PyExc_TypeError, QObject::tr("invalid tab-position specified.","python error").toUtf8().constData());
 				return nullptr;
 			}
 
@@ -219,11 +226,22 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 									"utf-8", fillColor.ptr(), &fillShade, "utf-8", strokeColor.ptr(), &strokeShade, &baselineOffset, &shadowXOffset,
 									&shadowYOffset, &outlineWidth, &underlineOffset, &underlineWidth, &strikethruOffset, &strikethruWidth,
 									&scaleH, &scaleV, &tracking, "utf-8", language.ptr(), "utf-8", fontFeatures.ptr()))
+	{
+		// Some old python versions leave bad pointers behind when an argument parsing error occurs
+		// so we can't free the memory safely in this case
+		name.resetDontFree();
+		font.resetDontFree();
+		features.resetDontFree();
+		fillColor.resetDontFree();
+		fontFeatures.resetDontFree();
+		strokeColor.resetDontFree();
+		language.resetDontFree();
 		return nullptr;
+	}
 	
 	if (name.isEmpty())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty char style name.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty char style name.","python error").toUtf8().constData());
 		return nullptr;
 	}
 
@@ -232,7 +250,7 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	{
 		if (!currentDoc->AllFonts->contains(realFont))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified font is not available.", "python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified font is not available.", "python error").toUtf8().constData());
 			return nullptr;
 		}
 	}
@@ -244,7 +262,7 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	{
 		if ((qFillColor != CommonStrings::None) && (!docColors.contains(qFillColor)))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified fill color is not available in document.", "python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified fill color is not available in document.", "python error").toUtf8().constData());
 			return nullptr;
 		}
 	}
@@ -252,7 +270,7 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	{
 		if ((qStrokeColor != CommonStrings::None) && (!docColors.contains(qStrokeColor)))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified stroke color is not available in document.", "python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified stroke color is not available in document.", "python error").toUtf8().constData());
 			return nullptr;
 		}
 	}
@@ -326,7 +344,10 @@ PyObject *scribus_createcustomlinestyle(PyObject * /* self */, PyObject* args)
 	PyObject *obj;
 
 	if (!PyArg_ParseTuple(args, "esO", "utf-8", name.ptr(), &obj))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 
 	if (!PyList_Check(obj)) {
 		PyErr_SetString(PyExc_TypeError, "'style' must be list.");
@@ -395,7 +416,7 @@ PyObject *scribus_createcustomlinestyle(PyObject * /* self */, PyObject* args)
 
 		if (!docColors.contains(sl.Color))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified color is not available in document.", "python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified color is not available in document.", "python error").toUtf8().constData());
 			return nullptr;
 		}
 		ml.push_back(sl);
