@@ -21,6 +21,17 @@ for which a new license (GPL+exception) is in place.
  *                                                                         *
  ***************************************************************************/
 
+#include <cstdlib>
+#include <iostream>
+
+#include <QApplication>
+#include <QByteArray>
+#include <QMessageBox>
+#include <QPixmap>
+#include <QRegExp>
+#include <QString>
+#include <QWidget>
+
 // include cmdvar.h first, as it pulls in <Python.h>
 #include "cmdannotations.h"
 #include "cmdvar.h"
@@ -60,35 +71,22 @@ for which a new license (GPL+exception) is in place.
 
 #include "api/api_application.h"
 
-#include <QApplication>
-#include <QMessageBox>
-#include <QTextCodec>
-#include <QRegExp>
-#include <QPixmap>
-#include <QWidget>
-#include <QString>
-//Added by qt3to4:
-#include <QByteArray>
-#include <cstdlib>
-#include <iostream>
-
-
 #ifdef HAVE_SCRIPTER2
 extern void scripter2_init();
 #endif
 
 // Exceptions; visible from cmdvar.h, set up in initscribus()
-PyObject* ScribusException;
-PyObject* NoDocOpenError;
-PyObject* WrongFrameTypeError;
-PyObject* NoValidObjectError;
-PyObject* NotFoundError;
-PyObject* NameExistsError;
+PyObject* ScribusException = nullptr;
+PyObject* NoDocOpenError = nullptr;
+PyObject* WrongFrameTypeError = nullptr;
+PyObject* NoValidObjectError = nullptr;
+PyObject* NotFoundError = nullptr;
+PyObject* NameExistsError = nullptr;
 
 // Other extern variables defined in cmdvar.h
-PyObject* wrappedMainWindow;
-PyObject* wrappedQApp;
-ScripterCore* scripterCore;
+PyObject* wrappedMainWindow = nullptr;
+PyObject* wrappedQApp = nullptr;
+ScripterCore* scripterCore = nullptr;
 
 
 int scriptplugin_getPluginAPIVersion()
@@ -338,6 +336,7 @@ PyMethodDef scribus_methods[] = {
 	{ "getAllText", scribus_getalltext, METH_VARARGS, tr(scribus_getalltext__doc__)},
 	{ "getBaseLine", (PyCFunction) scribus_getbaseline, METH_NOARGS, tr(scribus_getbaseline__doc__)},
 	{ "getBleeds", scribus_getbleeds, METH_NOARGS, tr(scribus_getbleeds__doc__)},
+	{ "getBoundingBox", scribus_getboundingbox, METH_VARARGS, tr(scribus_getboundingbox__doc__)},
 	{ "getCellColumnSpan", scribus_getcellcolumnspan, METH_VARARGS, tr(scribus_getcellcolumnspan__doc__)},
 	{ "getCellFillColor", scribus_getcellfillcolor, METH_VARARGS, tr(scribus_getcellfillcolor__doc__)},
 	{ "getCellRowSpan", scribus_getcellrowspan, METH_VARARGS, tr(scribus_getcellrowspan__doc__)},
@@ -355,6 +354,7 @@ PyMethodDef scribus_methods[] = {
 	{ "getColumns", scribus_getcolumns, METH_VARARGS, tr(scribus_getcolumns__doc__)},
 	{ "getColumnGuides", (PyCFunction) scribus_getColumnGuides, METH_VARARGS|METH_KEYWORDS, tr(scribus_getColumnGuides__doc__)},
 	{ "getCornerRadius", scribus_getcornerradius, METH_VARARGS, tr(scribus_getcornerradius__doc__)},
+	{ "getCurrentPageSize", (PyCFunction) scribus_getcurrentpagesize, METH_NOARGS, tr(scribus_getcurrentpagesize__doc__)},
 	{ "getCustomLineStyle", scribus_getcustomlinestyle, METH_VARARGS, tr(scribus_getcustomlinestyle__doc__)},
 	{ "getDocName", (PyCFunction) scribus_getdocname, METH_NOARGS, tr(scribus_getdocname__doc__)},
 	{ "getFillBlendmode", scribus_getfillblendmode, METH_VARARGS, tr(scribus_getfillblendmode__doc__)},
@@ -395,6 +395,7 @@ PyMethodDef scribus_methods[] = {
 	{ "getLineWidth", scribus_getlinewidth, METH_VARARGS, tr(scribus_getlinewidth__doc__)},
 	{ "getMargins", scribus_getmargins, METH_NOARGS, tr(scribus_getmargins__doc__) },
 	{ "getMasterPage", scribus_getmasterpage, METH_VARARGS, tr(scribus_getmasterpage__doc__)},
+	{ "getMinWordTracking", scribus_getminwordtracking, METH_VARARGS, tr(scribus_getminwordtracking__doc__) },
 	{ "getNextLinkedFrame", scribus_getnextlinkedframe, METH_VARARGS, tr(scribus_getnextlinkedframe__doc__)},
 	{ "getObjectAttributes", scribus_getobjectattributes, METH_VARARGS, tr(scribus_getobjectattributes__doc__)},
 	{ "getObjectType", scribus_getobjecttype, METH_VARARGS, tr(scribus_getobjecttype__doc__)},
@@ -429,7 +430,10 @@ PyMethodDef scribus_methods[] = {
 	{ "getTextLines", scribus_gettextlines, METH_VARARGS, tr(scribus_gettextlines__doc__)},
 	{ "getTextShade", scribus_gettextshade, METH_VARARGS, tr(scribus_gettextshade__doc__)},
 	{ "getTextVerticalAlignment", scribus_gettextverticalalignment, METH_VARARGS, tr(scribus_gettextverticalalignment__doc__)},
+	{ "getTracking", scribus_gettracking, METH_VARARGS, tr(scribus_gettracking__doc__) },
 	{ "getUnit", (PyCFunction) scribus_getunit, METH_NOARGS, tr(scribus_getunit__doc__)},
+	{ "getVisualBoundingBox", scribus_getvisualboundingbox, METH_VARARGS, tr(scribus_getvisualboundingbox__doc__) },
+	{ "getWordTracking", scribus_getwordtracking, METH_VARARGS, tr(scribus_getwordtracking__doc__) },
 	{ "pointsToDocUnit", scribus_pointstodocunit, METH_VARARGS, tr(scribus_pointstodocunit__doc__)},
 	{ "docUnitToPoints", scribus_docunittopoints, METH_VARARGS, tr(scribus_docunittopoints__doc__)},
 	{ "stringValueToPoints", scribus_stringvaluetopoints, METH_VARARGS, tr(scribus_stringvaluetopoints__doc__)},
@@ -529,6 +533,7 @@ PyMethodDef scribus_methods[] = {
 	{ "setColumns", scribus_setcolumns, METH_VARARGS, tr(scribus_setcolumns__doc__)},
 	{ "setColumnGuides", (PyCFunction) scribus_setColumnGuides, METH_VARARGS|METH_KEYWORDS, tr(scribus_setColumnGuides__doc__)},
 	{ "setCornerRadius", scribus_setcornerradius, METH_VARARGS, tr(scribus_setcornerradius__doc__)},
+	{ "setCurrentPageSize", scribus_setcurrentpagesize, METH_VARARGS, tr(scribus_setcurrentpagesize__doc__) },
 	{ "setCursor", scribus_setcursor, METH_VARARGS, tr(scribus_setcursor__doc__)},
 	{ "setCustomLineStyle", scribus_setcustomlinestyle, METH_VARARGS, tr(scribus_setcustomlinestyle__doc__)},
 	{ "setDocType", scribus_setdoctype, METH_VARARGS, tr(scribus_setdoctype__doc__)},
@@ -569,6 +574,7 @@ PyMethodDef scribus_methods[] = {
 	{ "setLineTransparency", scribus_setlinetrans, METH_VARARGS, tr(scribus_setlinetrans__doc__)},
 	{ "setLineWidth", scribus_setlinewidth, METH_VARARGS, tr(scribus_setlinewidth__doc__)},
 	{ "setMargins", scribus_setmargins, METH_VARARGS, tr(scribus_setmargins__doc__)},
+	{ "setMinWordTracking", scribus_setminwordtracking, METH_VARARGS, tr(scribus_setminwordtracking__doc__) },
 	{ "setMultiLine", scribus_setmultiline, METH_VARARGS, tr(scribus_setmultiline__doc__)},
 	{ "setNewName", scribus_setitemname, METH_VARARGS, tr(scribus_setitemname__doc__)}, // Deprecated, was in fact never documented
 	{ "setObjectAttributes", scribus_setobjectattributes, METH_VARARGS, tr(scribus_setobjectattributes__doc__)},
@@ -598,8 +604,10 @@ PyMethodDef scribus_methods[] = {
 	{ "setTextShade", scribus_settextshade, METH_VARARGS, tr(scribus_settextshade__doc__)},
 	{ "setTextStroke", scribus_settextstroke, METH_VARARGS, tr(scribus_settextstroke__doc__)},
 	{ "setTextVerticalAlignment", scribus_settextverticalalignment, METH_VARARGS, tr(scribus_settextverticalalignment__doc__)},
+	{ "setTracking", scribus_settracking, METH_VARARGS, tr(scribus_settracking__doc__) },
 	{ "setUnit", scribus_setunit, METH_VARARGS, tr(scribus_setunit__doc__)},
 	{ "setVGuides", scribus_setVguides, METH_VARARGS, tr(scribus_setVguides__doc__)},
+	{ "setWordTracking", scribus_setwordtracking, METH_VARARGS, tr(scribus_setwordtracking__doc__) },
 	{ "sizeObject", scribus_sizeobject, METH_VARARGS, tr(scribus_sizeobject__doc__)},
 	{ "statusMessage", scribus_statusmessage, METH_VARARGS, tr(scribus_statusmessage__doc__)},
 	{ "textFlowMode", scribus_settextflowmode, METH_VARARGS, tr(scribus_textflowmode__doc__)}, // Deprecated
@@ -627,8 +635,8 @@ PyMethodDef scribus_methods[] = {
 	// by Tj (hacker@iam.tj>
 	{ "combinePolygons", (PyCFunction) scribus_combinepolygons, METH_NOARGS, tr(scribus_combinepolygons__doc__)},
 	// Internal methods - Not for public use
-	{ "retval", (PyCFunction) scribus_retval, METH_VARARGS,  "Scribus internal."},
-	{ "getval", (PyCFunction) scribus_getval, METH_NOARGS,  "Scribus internal."},
+	{ "retval", (PyCFunction) scribus_retval, METH_VARARGS, "Scribus internal." },
+	{ "getval", (PyCFunction) scribus_getval, METH_NOARGS, "Scribus internal." },
 	{ "setLinkAnnotation", scribus_setlinkannotation, METH_VARARGS,tr(scribus_setlinkannotation__doc__)},
 	{ "setFileAnnotation", (PyCFunction) scribus_setfileannotation, METH_VARARGS|METH_KEYWORDS,tr(scribus_setfileannotation__doc__)},
 	{ "setURIAnnotation", scribus_seturiannotation, METH_VARARGS,tr(scribus_seturiannotation__doc__)},
