@@ -46,12 +46,6 @@ using namespace std;
 ScPs2OutputParams::ScPs2OutputParams(ScribusDoc* doc)
 {
 	document = doc;
-	colorMode = ScPainterExBase::rgbMode;
-	hProfile = nullptr;
-	rgbToOutputColorTransform = nullptr;
-	rgbToOutputImageTransform = nullptr;
-	cmykToOutputColorTransform = nullptr;
-	cmykToOutputImageTransform = nullptr;
 }
 
 ScPainterEx_Ps2::ScPainterEx_Ps2(QIODevice* iodev, const QRect& rect, const ScPs2OutputParams& options )
@@ -72,10 +66,6 @@ ScPainterEx_Ps2::ScPainterEx_Ps2(QIODevice* iodev, const QRect& rect, const ScPs
 	clear();
 }
 
-ScPainterEx_Ps2::~ScPainterEx_Ps2()
-{
-}
-
 ScPainterExBase::ImageMode ScPainterEx_Ps2::imageMode() const
 {
 	ImageMode imageMode;
@@ -178,6 +168,11 @@ void ScPainterEx_Ps2::scale( double x, double y )
 	m_matrix.scale(x, y);
 }
 
+void ScPainterEx_Ps2::shear(double x, double y)
+{
+	m_matrix.shear(x, y);
+}
+
 void ScPainterEx_Ps2::moveTo( const double &x, const double &y )
 {
 	FPoint pp( x, y );
@@ -192,7 +187,7 @@ void ScPainterEx_Ps2::lineTo( const double &x, const double &y )
 	m_stream << QString("%1 %2 lineto\n").arg(pp.x()).arg(pp.y());
 }
 
-void ScPainterEx_Ps2::curveTo( FPoint p1, FPoint p2, FPoint p3 )
+void ScPainterEx_Ps2::curveTo(const FPoint& p1, const FPoint& p2, const FPoint& p3)
 {
 	FPoint pps[3];
 	pps[0].setXY( p1.x(), p1.y() );
@@ -229,7 +224,7 @@ void ScPainterEx_Ps2::setStrokeMode( int stroke )
 	m_strokeMode = stroke;
 }
 
-void ScPainterEx_Ps2::setGradient(VGradientEx::Type mode, FPoint orig, FPoint vec, FPoint foc, double scale, double skew)
+void ScPainterEx_Ps2::setGradient(VGradientEx::Type mode, const FPoint& orig, const FPoint& vec, const FPoint& foc, double scale, double skew)
 {
 	m_fillGradient.setType(mode);
 	m_fillGradient.setOrigin(orig);
@@ -242,16 +237,16 @@ void ScPainterEx_Ps2::setGradient(VGradientEx::Type mode, FPoint orig, FPoint ve
 	m_strokeGradient.setFocalPoint(foc);
 }
 
-void ScPainterEx_Ps2::setPattern(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
+void ScPainterEx_Ps2::setPattern(ScPattern *pattern, const ScPatternTransform& patternTrans, bool mirrorX, bool mirrorY)
 {
 	m_pattern = pattern;
-	m_patternScaleX = scaleX / 100.0;
-	m_patternScaleY = scaleY / 100.0;
-	m_patternOffsetX = offsetX;
-	m_patternOffsetY = offsetY;
-	m_patternRotation = rotation;
-	m_patternSkewX   = skewX;
-	m_patternSkewY   = skewY;
+	m_patternScaleX = patternTrans.scaleX;
+	m_patternScaleY = patternTrans.scaleY;
+	m_patternOffsetX = patternTrans.offsetX;
+	m_patternOffsetY = patternTrans.offsetY;
+	m_patternRotation = patternTrans.rotation;
+	m_patternSkewX   = patternTrans.skewX;
+	m_patternSkewY   = patternTrans.skewY;
 	m_patternMirrorX = mirrorX;
 	m_patternMirrorY = mirrorY;
 }
@@ -450,7 +445,7 @@ void ScPainterEx_Ps2::putColor(const ScColorShade& colorShade, bool doFill)
 	{
 		unsigned long colorIn[4];
 		unsigned long colorOut[4];
-		ScColorTransform cmsTranform = nullptr;
+		ScColorTransform cmsTranform;
 		if (colorShade.color.getColorModel() == colorModelRGB)
 		{
 			RGBColorF rgb;
@@ -744,7 +739,7 @@ void ScPainterEx_Ps2::writeRGBImageToStream_Ascii85( ScImage* image )
 						m_stream << "z";
 					else
 						m_stream << ascii85;
-					written += ((allZero) ? 1 : 5);
+					written += (allZero ? 1 : 5);
 					if (written > 75)
 					{
 						m_stream << "\n";
@@ -820,7 +815,7 @@ void ScPainterEx_Ps2::writeCMYKImageToStream_Ascii85( ScImage* image )
 				m_stream << "z";
 			else
 				m_stream << ascii85;
-			written += ((allZero) ? 1 : 5);
+			written += (allZero ? 1 : 5);
 			if (written > 75)
 			{
 				m_stream << "\n";
@@ -908,7 +903,7 @@ void ScPainterEx_Ps2::drawPolyLine()
 	strokePath();
 }
 
-void ScPainterEx_Ps2::drawLine(FPoint start, FPoint end)
+void ScPainterEx_Ps2::drawLine(const FPoint& start, const FPoint& end)
 {
 	newPath();
 	moveTo(start.x(), start.y());
