@@ -26,10 +26,7 @@ ScPlugin::~ScPlugin()
 {
 }
 
-bool ScPlugin::newPrefsPanelWidget( QWidget* /* parent */,
-									Prefs_Pane*& /* panel */,
-									QString& /* caption */,
-									QPixmap& /* icon */)
+bool ScPlugin::newPrefsPanelWidget( QWidget* /* parent */, Prefs_Pane*& /* panel */)
 {
 	return false;
 }
@@ -81,30 +78,6 @@ void ScPlugin::changedDoc(ScribusDoc* )
 
 ScActionPlugin::ScActionPlugin() : ScPlugin()
 {
-	m_Doc = nullptr;
-
-	m_actionInfo.name = "";
-	m_actionInfo.text = "";
-	m_actionInfo.helpText = "";
-	m_actionInfo.keySequence = "";
-	m_actionInfo.menu = "";
-	m_actionInfo.menuAfterName = "";
-	m_actionInfo.parentMenu = "";
-	m_actionInfo.subMenuName = "";
-	m_actionInfo.toolbar = "";
-	m_actionInfo.toolBarName = "";
-	m_actionInfo.icon1 = QPixmap();
-	m_actionInfo.icon2 = QPixmap();
-	m_actionInfo.notSuitableFor.clear();
-	m_actionInfo.forAppMode.clear();
-	m_actionInfo.needsNumObjects = -1;
-	m_actionInfo.firstObjectType.clear();
-	m_actionInfo.secondObjectType.clear();
-	m_actionInfo.enabledOnStartup = false;
-	m_actionInfo.enabledForStoryEditor = false;
-	m_actionInfo.seMenu = "";
-	m_actionInfo.seParentMenu = "";
-	m_actionInfo.seKeySequence = "";
 }
 
 ScActionPlugin::~ScActionPlugin()
@@ -149,7 +122,7 @@ const ScActionPlugin::ActionInfo & ScActionPlugin::actionInfo() const
 
 bool ScActionPlugin::handleSelection(ScribusDoc* doc, int SelectedType)
 {
-	const int docSelectionCount=doc->m_Selection->count();
+	const int docSelectionCount = doc->m_Selection->count();
 	ActionInfo ai(actionInfo());
 	if (SelectedType != -1)
 	{
