@@ -14,22 +14,21 @@ for which a new license (GPL+exception) is in place.
 
 class ScASCII85EncodeFilter : public ScStreamFilter
 {
-protected:
-
-	QByteArray     m_buffer;
-	int            m_buffer_pending;
-
-	unsigned char  m_four_tuple[4];
-	int            m_four_tuple_pending;
-
 public:
 	ScASCII85EncodeFilter(QDataStream* stream);
 	ScASCII85EncodeFilter(ScStreamFilter* filter);
 
-	virtual bool openFilter ();
-	virtual bool closeFilter();
+	bool openFilter () override;
+	bool closeFilter() override;
 
-	virtual bool writeData(const char* data, int dataLen);
+	bool writeData(const char* data, int dataLen) override;
+
+protected:
+	QByteArray     m_buffer;
+	int            m_buffer_pending { 0 };
+
+	unsigned char  m_four_tuple[4] { 0 };
+	int            m_four_tuple_pending { 0 };
 };
 
 #endif
