@@ -20,7 +20,6 @@ for which a new license (GPL+exception) is in place.
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QHBoxLayout>
-#include <QVBoxLayout>
 #include <QLabel>
 #include <QLineEdit>
 #include <QPixmap>
@@ -29,6 +28,7 @@ for which a new license (GPL+exception) is in place.
 #include <QSpacerItem>
 #include <QStackedWidget>
 #include <QStringList>
+#include <QVBoxLayout>
 
 #include "annota.h"
 #include "commonstrings.h"
@@ -52,7 +52,7 @@ Annota::Annota(QWidget* parent, PageItem *it, ScribusDoc* doc, ScribusView* view
 	setModal(true);
 	setWindowTitle( tr( "Annotation Properties" ) );
 
-	m_pageCount = m_doc->DocPages.count(),
+	m_pageCount = m_doc->DocPages.count();
 	m_width = static_cast<int>(m_doc->pageWidth());
 	m_height = static_cast<int>(m_doc->pageHeight());
 	m_oriWidth = static_cast<int>(m_doc->pageWidth());
@@ -280,17 +280,17 @@ void Annota::SetPage(double v)
 
 void Annota::SetCross()
 {
-	int x,y;
 	disconnect(navigator, SIGNAL(Coords(double, double)), this, SLOT(SetCoords(double, double)));
-	x = static_cast<int>(xSpin->value() / static_cast<double>(m_width) * navigator->pmx.width());
-	y = static_cast<int>(ySpin->value() / static_cast<double>(m_height) * navigator->pmx.height());
+	int x = static_cast<int>(xSpin->value() / static_cast<double>(m_width) * navigator->pmx.width());
+	int y = static_cast<int>(ySpin->value() / static_cast<double>(m_height) * navigator->pmx.height());
 	navigator->drawMark(x, y);
 	connect(navigator, SIGNAL(Coords(double, double)), this, SLOT(SetCoords(double, double)));
 }
 
 void Annota::SetValues()
 {
-	QString tmp, tmp2;
+	QString tmp;
+	QString tmp2;
 	m_item->annotation().setZiel(pageSpin->value() - 1);
 	if (m_view->m_doc->masterPageMode())
 		m_item->annotation().setType(typeCombo->currentIndex() + 11);
