@@ -51,29 +51,15 @@ BookMItem::BookMItem(QTreeWidget* parent, struct ScribusDoc::BookMa *Bm)
 }
 
 BookMItem::BookMItem(QTreeWidget* parent, QTreeWidgetItem* after, int nr, PageItem* PObject)
-	: QTreeWidgetItem(parent, after)
+	: QTreeWidgetItem(parent, after), PageObject(PObject), ItemNr(nr)
 {
-	ItemNr = nr;
-	PageObject = PObject;
-	Action = "";
-	First = 0;
-	Last = 0;
-	Prev = 0;
-	Next = 0;
-	Pare = 0;
+
 }
 
 BookMItem::BookMItem(QTreeWidget* parent, int nr, PageItem* PObject)
-	: QTreeWidgetItem(parent)
+	: QTreeWidgetItem(parent), PageObject(PObject), ItemNr(nr)
 {
-	ItemNr = nr;
-	PageObject = PObject;
-	Action = "";
-	First = 0;
-	Last = 0;
-	Prev = 0;
-	Next = 0;
-	Pare = 0;
+
 }
 
 void BookMItem::setup(struct ScribusDoc::BookMa *Bm)
@@ -96,10 +82,10 @@ QString BookMItem::key(int, bool) const
 	return tmp;
 }
 
-int BookMItem::level()
+int BookMItem::level() const
 {
 	int ret = 0; // 0 = top level
-	QTreeWidgetItem * p = parent();
+	const QTreeWidgetItem * p = parent();
 	while (p)
 	{
 		++ret;
@@ -111,10 +97,6 @@ int BookMItem::level()
 
 BookmarkView::BookmarkView(QWidget* parent) : QTreeWidget(parent)
 {
-	NrItems = 0;
-	First = 1;
-	Last = 0;
-
 	setAcceptDrops(true);
 	setSelectionMode(QAbstractItemView::SingleSelection);
 	setDragEnabled(true);
@@ -128,13 +110,14 @@ BookmarkView::BookmarkView(QWidget* parent) : QTreeWidget(parent)
 
 void BookmarkView::addPageItem(PageItem* ite)
 {
-	QString bm, bm2;
+	QString bm;
+	QString bm2;
 	getTextAndTitle(ite, bm, bm2);
 	addItem(bm, bm2, ite);
 	Last = NrItems;
 }
 
-void BookmarkView::getTextAndTitle(PageItem* item, QString& text, QString& title)
+void BookmarkView::getTextAndTitle(PageItem* item, QString& text, QString& title) const
 {
 	QChar ch;
 	QString str;
@@ -166,7 +149,7 @@ void BookmarkView::getTextAndTitle(PageItem* item, QString& text, QString& title
 
 void BookmarkView::selectPageItem(QTreeWidgetItem * current, int /*column*/)
 {
-	BookMItem * bookmark = dynamic_cast<BookMItem*>(current);
+	auto* bookmark = dynamic_cast<BookMItem*>(current);
 	// something weird here at 1st call...
 	if (bookmark)
 		emit selectElement(bookmark->PageObject, false);
@@ -189,7 +172,7 @@ void BookmarkView::rebuildTree()
 	QTreeWidgetItemIterator it1(this, QTreeWidgetItemIterator::All);
 	while (*it1)
 	{
-		BookMItem * currItem = (BookMItem*)(*it1);
+		auto* currItem = (BookMItem*) (*it1);
 		currItem->ItemNr = ++Last;
 		++it1;
 	}
@@ -198,13 +181,14 @@ void BookmarkView::rebuildTree()
 	QTreeWidgetItemIterator it2(this, QTreeWidgetItemIterator::All);
 	while (*it2)
 	{
-		BookMItem * currItem = (BookMItem*)(*it2);
+		auto* currItem = (BookMItem*) (*it2);
 		// handle parents
-		BookMItem * parent = (BookMItem*)currItem->parent();
+		const auto* parent = (BookMItem*) currItem->parent();
 		currItem->Pare = parent ? parent->ItemNr : 0;
 		if (currItem->Pare == 0) // top level item
 		{
-			BookMItem *prev   = nullptr, *next = nullptr;
+			const BookMItem* prev = nullptr;
+			const BookMItem* next = nullptr;
 			int topLevelIndex = this->indexOfTopLevelItem(currItem);
 			if (topLevelIndex >= 0)
 			{
@@ -221,9 +205,11 @@ void BookmarkView::rebuildTree()
 		int childCount  = currItem->childCount();
 		if (childCount > 0)
 		{
-			BookMItem * child = nullptr, *prev = nullptr, *next = nullptr;
-			BookMItem * firstChild = (BookMItem*) currItem->child(0);
-			BookMItem * lastChild  = (BookMItem*) currItem->child(childCount - 1);
+			BookMItem* child = nullptr;
+			const BookMItem* prev = nullptr;
+			const BookMItem* next = nullptr;
+			const auto* firstChild = (BookMItem*) currItem->child(0);
+			const auto* lastChild = (BookMItem*) currItem->child(childCount - 1);
 			currItem->First = firstChild->ItemNr;
 			currItem->Last  = lastChild->ItemNr;
 			for (int i = 0; i < childCount; ++i)
@@ -246,7 +232,7 @@ void BookmarkView::rebuildTree()
 
 void BookmarkView::addItem(const QString& text, const QString& Tit, PageItem *PageObject)
 {
-	BookMItem * ite = new BookMItem(this, NrItems+1, PageObject);
+	auto* ite = new BookMItem(this, NrItems + 1, PageObject);
 	ite->setText(0, text);
 	ite->Title = Tit;
 	rebuildTree();
@@ -255,7 +241,7 @@ void BookmarkView::addItem(const QString& text, const QString& Tit, PageItem *Pa
 void BookmarkView::deleteItem(PageItem *pObject)
 {
 	QTreeWidgetItemIterator it(this);
-	BookMItem * item;
+	const BookMItem * item;
 	while (*it)
 	{
 		item = (BookMItem*)(*it);
@@ -269,7 +255,7 @@ void BookmarkView::deleteItem(PageItem *pObject)
 	rebuildTree();
 }
 
-void BookmarkView::setAction(PageItem *currItem, const QString& Act)
+void BookmarkView::setAction(const PageItem *currItem, const QString& Act)
 {
 	BookMItem *ite;
 	QTreeWidgetItemIterator it(this);
@@ -288,7 +274,8 @@ void BookmarkView::setAction(PageItem *currItem, const QString& Act)
 void BookmarkView::changeText(PageItem *currItem)
 {
 	BookMItem *ite;
-	QString bm, bm2;
+	QString bm;
+	QString bm2;
 
 	getTextAndTitle(currItem, bm, bm2);
 
