@@ -47,7 +47,7 @@ public:
 	~GradientEditor() {};
 
 	void setGradient(const VGradient& grad);
-	const VGradient &gradient();
+	const VGradient& gradient() const;
 	void setColors(ColorList &colorList);
 	QColor setColor(const QString& colorName, int shad);
 	void setGradientEditable(bool val);
