@@ -21,9 +21,9 @@ for which a new license (GPL+exception) is in place.
 
 NodePalette::NodePalette( QWidget* parent) : ScrPaletteBase(parent, "nodePalette", false, Qt::WindowFlags())
 {
-	QSize iconSize = QSize(22, 22);
-	QSize buttonSize = QSize(24, 24);
-	QSize maxButtonSize = QSize(16777215, buttonSize.height());
+	QSize iconSize(22, 22);
+	QSize buttonSize(24, 24);
+	QSize maxButtonSize(16777215, buttonSize.height());
 	QSizePolicy::Policy buttonSizePolicy = static_cast<QSizePolicy::Policy>(QSizePolicy::GrowFlag | QSizePolicy::ExpandFlag);
 
 	m_doc = nullptr;
@@ -508,14 +508,14 @@ void NodePalette::doReduce()
 {
 	if (m_doc == nullptr)
 		return;
-	m_view->TransformPoly(8, 1, value2pts(scaleDistance->value(),m_doc->unitIndex()));
+	m_view->TransformPoly(8, 1, scaleDistance->getValue(SC_PT));
 }
 
 void NodePalette::doEnlarge()
 {
 	if (m_doc == nullptr)
 		return;
-	m_view->TransformPoly(9, 1, value2pts(scaleDistance->value(),m_doc->unitIndex()));
+	m_view->TransformPoly(9, 1, scaleDistance->getValue(SC_PT));
 }
 
 void NodePalette::ShearR()
