@@ -176,17 +176,16 @@ OutputPreview_PS::OutputPreview_PS(QWidget* parent, ScribusDoc* doc) :
 	m_optionsUi->coverThresholdValue->setValue(m_prefsManager.appPrefs.psOutputPreviewPrefs.inkCoverageThreshold);
 
 	// Generate a template name for temporary files
-	QTemporaryFile *tempFile = new QTemporaryFile(ScPaths::tempFileDir() + "/scpreview_XXXXXX.ps");
-	if (tempFile->open())
+	QTemporaryFile tempFile(ScPaths::tempFileDir() + "/scpreview_XXXXXX.ps");
+	if (tempFile.open())
 	{
-		QString tempFileBase = tempFile->fileName();
-		tempFile->setAutoRemove(false);
-		tempFile->close();
+		QString tempFileBase = tempFile.fileName();
+		tempFile.setAutoRemove(false);
+		tempFile.close();
 		m_tempBaseName = QFileInfo(tempFileBase).completeBaseName();
 	}
 	if (m_tempBaseName.isEmpty())
 		m_tempBaseName = "scpreview";
-	delete tempFile;
 
 	if (m_printOptions.firstUse)
 		PrinterUtil::getDefaultPrintOptions(m_printOptions, m_doc->bleedsVal());
