@@ -21,20 +21,7 @@ PageItem* PropertyWidgetBase::currentItemFromSelection()
 		return nullptr;
 
 	PageItem *currentItem = nullptr;
-
-	if (m_doc->m_Selection->count() > 1)
-	{
-		/*uint lowestItem = 999999;
-			for (int a=0; a<m_doc->m_Selection->count(); ++a)
-			{
-				currentItem = m_doc->m_Selection->itemAt(a);
-				lowestItem = qMin(lowestItem, currentItem->ItemNr);
-			}
-			currentItem = m_doc->Items->at(lowestItem);*/
+	if (m_doc->m_Selection->count() > 0)
 		currentItem = m_doc->m_Selection->itemAt(0);
-	}
-	else if (m_doc->m_Selection->count() == 1)
-		currentItem = m_doc->m_Selection->itemAt(0);
-
 	return currentItem;
 }
