@@ -21,14 +21,15 @@ for which a new license (GPL+exception) is in place.
  *                                                                         *
  ***************************************************************************/
 
-#ifndef TPALETTE_H
-#define TPALETTE_H
+#ifndef TRANSPARENCYPALETTE_H
+#define TRANSPARENCYPALETTE_H
 
-#include <QWidget>
 #include <QPointer>
 #include <QGroupBox>
 #include <QPushButton>
 #include <QToolButton>
+#include <QWidget>
+
 #include "scribusapi.h"
 #include "gradienteditor.h"
 #include "scribusdoc.h"
@@ -37,11 +38,11 @@ for which a new license (GPL+exception) is in place.
 #include "ui/gradientvectordialog.h"
 #include "ui/patternpropsdialog.h"
 
-class PageItem;
 class ColorListBox;
+class LinkButton;
+class PageItem;
 class ScrSpinBox;
 class ScPattern;
-class LinkButton;
 
 /**
   *@author Franz Schmid
@@ -70,6 +71,9 @@ public:
 	void setGradients(QHash<QString, VGradient> *docGradients);
 	void setPatterns(QHash<QString, ScPattern> *docPatterns);
 
+	void setCurrentMaskPattern(const QString& pattern, const ScMaskTransform& maskTrans, bool mirrorX, bool mirrorY);
+	void setSpecialGradient(double x1, double y1, double x2, double y2, double fx, double fy, double sg, double sk);
+
 public slots:
 	void handleUpdateRequest(int);
 
@@ -84,9 +88,7 @@ public slots:
 	void setActiveGradDia(bool active);
 	void hideEditedPatterns(QStringList names);
 	void selectPattern(QListWidgetItem *c);
-	void setActPattern(const QString& pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY);
 	void changePatternProps();
-	void setSpecialGradient(double x1, double y1, double x2, double y2, double fx, double fy, double sg, double sk);
 	void setActTrans(double, double);
 	void setActBlend(int, int);
 	void slotTransS(double val);
@@ -113,13 +115,7 @@ protected:
 	int currentUnit {0};
 	QHash<QString, ScPattern> *patternList {nullptr};
 	QHash<QString, VGradient> *gradientList {nullptr};
-	double m_Pattern_scaleX {0.0};
-	double m_Pattern_scaleY {0.0};
-	double m_Pattern_offsetX {0.0};
-	double m_Pattern_offsetY {0.0};
-	double m_Pattern_rotation {0.0};
-	double m_Pattern_skewX {0.0};
-	double m_Pattern_skewY {0.0};
+	ScMaskTransform m_maskTransform;
 	bool m_Pattern_mirrorX {false};
 	bool m_Pattern_mirrorY {false};
 
