@@ -103,7 +103,7 @@ int callGS(const QStringList& args_in, const QString& device, const QString& fil
 
 int callGS(const QString& args_in, const QString& device)
 {
-	PrefsManager& prefsManager=PrefsManager::instance();
+	PrefsManager& prefsManager = PrefsManager::instance();
 	QString cmd1 = getShortPathName(prefsManager.ghostscriptExecutable());
 	cmd1 += " -q -dNOPAUSE -dQUIET -dPARANOIDSAFER -dBATCH";
 	// Choose rendering device
@@ -143,7 +143,7 @@ int callGS(const QString& args_in, const QString& device)
 
 int convertPS2PS(const QString& in, const QString& out, const QStringList& opts, int level)
 {
-	PrefsManager& prefsManager=PrefsManager::instance();
+	PrefsManager& prefsManager = PrefsManager::instance();
 	QStringList args;
 	args.append( "-q" );
 	args.append( "-dQUIET" );
@@ -180,7 +180,7 @@ int convertPS2PS(const QString& in, const QString& out, const QStringList& opts,
 
 int convertPS2PDF(const QString& in, const QString& out, const QStringList& opts)
 {
-	PrefsManager& prefsManager=PrefsManager::instance();
+	PrefsManager& prefsManager = PrefsManager::instance();
 	QStringList args;
 	args.append( "-q" );
 	args.append( "-dQUIET" );
@@ -333,7 +333,7 @@ QString getGSDefaultExeName()
 		}
 	}
 #endif
-#if defined Q_OS_MAC
+#if defined Q_OS_MACOS
 	QStringList gsPaths;
 	gsPaths << "/usr/bin/gs" << "/usr/local/bin/gs" << "/opt/local/bin/gs" << "/sw/bin/gs";
 	for (int i = 0; i < gsPaths.size(); ++i)
